import { AccountProductFields, AccountProductReturnType } from './accountProduct';
import { PlanFields, PlanReturnType } from './plan';
import { OperationFields } from './typeOptions';
import { SelectAccountProductReturnType } from './accountProduct';
import { SelectPlanReturnType } from './plan';
export declare type SelectAccountReturnType<S extends AccountFields> = {
    [P in keyof S]: P extends 'plan' ? SelectPlanReturnType<NonNullable<S['plan']>['fields']> : P extends 'products' ? Array<SelectAccountProductReturnType<NonNullable<S['products']>['fields']>> : P extends keyof AccountReturnType ? AccountReturnType[P] : AccountReturnType;
};
export interface AccountFields extends OperationFields {
    /**
     * The account's country two-letter code in ISO3166 format
     */
    country_code?: boolean;
    /**
     * The first day of the week for the account (sunday / monday)
     */
    first_day_of_the_week?: boolean;
    /**
     *  The account's unique identifier.
     */
    id?: boolean;
    /**
     * The account's logo.
     */
    logo?: boolean;
    /**
     * The account's name.
     */
    name?: boolean;
    /**
     * The account's payment plan.
     */
    plan?: {
        fields: PlanFields;
    };
    /**
     * The account's active products
     */
    products?: {
        fields: AccountProductFields;
    };
    /**
     * Show weekends in timeline
     */
    show_timeline_weekends?: boolean;
    /**
     * The product the account signed up to first.
     */
    sign_up_product_kind?: boolean;
    /**
     * The account's slug.
     */
    slug?: boolean;
    /**
     * The account's tier.
     */
    tier?: boolean;
}
export interface AccountReturnType {
    /**
     * The account's country two-letter code in ISO3166 format
     */
    country_code: string | null;
    /**
     * The first day of the week for the account (sunday / monday)
     */
    first_day_of_the_week: 'sunday' | 'monday' | null;
    /**
     *  The account's unique identifier.
     */
    id: number;
    /**
     * The account's logo.
     */
    logo: string | null;
    /**
     * The account's name.
     */
    name: string;
    /**
     * The account's payment plan.
     */
    plan: PlanReturnType | null;
    /**
     * The account's active products
     */
    products: AccountProductReturnType[] | null;
    /**
     * Show weekends in timeline
     */
    show_timeline_weekends: boolean;
    /**
     * The product the account signed up to first.
     */
    sign_up_product_kind: string | null;
    /**
     * The account's slug.
     */
    slug: string;
    /**
     * The account's tier.
     */
    tier: string | null;
}
//# sourceMappingURL=account.d.ts.map