/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ColumnReturnType } from '../column';
import { ColumnValueFields } from '../columnValue';
export declare type SelectLocationValueReturnType<S extends LocationValueFields> = {
    [P in keyof S]: P extends keyof LocationValueReturnType ? LocationValueReturnType[P] : LocationValueReturnType;
};
export interface LocationValueFields extends ColumnValueFields {
    /**
     * The column's address value.
     */
    address?: boolean;
    /**
     * The column's city value.
     */
    city?: boolean;
    /**
     * The column's shortened city value.
     */
    city_short?: boolean;
    /**
     * The column's country value.
     */
    country?: boolean;
    /**
     * The column's shortened country value.
     */
    country_short?: boolean;
    /**
     * The column's latitude value.
     */
    lat?: boolean;
    /**
     * The column's longitude value.
     */
    lng?: boolean;
    /**
     * The unique place identifier of the location.
     */
    place_id?: boolean;
    /**
     * The column's street value.
     */
    street?: boolean;
    /**
     * The column's street building number value.
     */
    street_number?: boolean;
    /**
     * The column's shortened street building number value.
     */
    street_number_short?: boolean;
    /**
     * The column's shortened street value.
     */
    street_short?: boolean;
    /**
     * The column's last updated date.
     */
    updated_at?: boolean;
}
export interface LocationValueReturnType extends ColumnReturnType {
    /**
     * The column's address value.
     */
    address?: string | null;
    /**
     * The column's city value.
     */
    city?: string | null;
    /**
     * The column's shortened city value.
     */
    city_short?: string | null;
    /**
     * The column's country value.
     */
    country?: string | null;
    /**
     * The column's shortened country value.
     */
    country_short?: string | null;
    /**
     * The column's latitude value.
     */
    lat?: number | null;
    /**
     * The column's longitude value.
     */
    lng?: number | null;
    /**
     * The unique place identifier of the location.
     */
    place_id?: string | null;
    /**
     * The column's street value.
     */
    street?: string | null;
    /**
     * The column's street building number value.
     */
    street_number?: string | null;
    /**
     * The column's shortened street building number value.
     */
    street_number_short?: string | null;
    /**
     * The column's shortened street value.
     */
    street_short?: string | null;
    /**
     * The column's last updated date.
     */
    updated_at?: string | null;
}
//# sourceMappingURL=locationValue.d.ts.map