/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ID } from '../../types/id';
import { ColumnReturnType } from '../column';
import { ColumnValueFields } from '../columnValue';
import { OperationFields } from '../typeOptions';
export declare type SelectStatusValueReturnType<S extends StatusValueFields> = {
    [P in keyof S]: P extends 'label_style' ? SelectLabelStyleReturnType<NonNullable<S['label_style']>['fields']> : P extends keyof StatusValueReturnType ? StatusValueReturnType[P] : StatusValueReturnType;
};
export interface StatusValueFields extends ColumnValueFields {
    /**
     * The column's status index in the board.
     */
    index?: boolean;
    /**
     * Whether or not the item's status is done.
     */
    is_done?: boolean;
    /**
     * The column's status label value.
     */
    label?: boolean;
    /**
     * The status label's style.
     */
    label_style?: {
        fields: LabelStyleFields;
    };
    /**
     * The column's last updated date.
     */
    update_id?: boolean;
}
export interface StatusValueReturnType extends ColumnReturnType {
    /**
     * The column's status index in the board.
     */
    index: number | null;
    /**
     * Whether or not the item's status is done.
     */
    is_done: boolean | null;
    /**
     * The column's status label value.
     */
    label: string | null;
    /**
     * The status label's style.
     */
    label_style: LabelStyleReturnType | null;
    /**
     * The column's last updated date.
     */
    update_id: ID | null;
}
export declare type SelectLabelStyleReturnType<S extends LabelStyleFields> = {
    [P in keyof S]: P extends keyof LabelStyleReturnType ? LabelStyleReturnType[P] : LabelStyleReturnType;
};
export interface LabelStyleFields extends OperationFields {
    /**
     * The label's border Hex color code.
     */
    border?: boolean;
    /**
     * The label's Hex color code.
     */
    color?: boolean;
}
export interface LabelStyleReturnType {
    /**
     * The label's border Hex color code.
     */
    border: string | null;
    /**
     * The label's Hex color code.
     */
    color: string | null;
}
//# sourceMappingURL=statusValue.d.ts.map