/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ColumnReturnType } from '../column';
import { ColumnValueFields } from '../columnValue';
import { OperationFields } from '../typeOptions';
export declare type SelectTimeTrackingValueReturnType<S extends TimeTrackingValueFields> = {
    [P in keyof S]: P extends 'history' ? Array<SelectTimeTrackingHistoryItemReturnType<NonNullable<S['history']>['fields']>> : P extends keyof TimeTrackingValueReturnType ? TimeTrackingValueReturnType[P] : TimeTrackingValueReturnType;
};
export interface TimeTrackingValueFields extends ColumnValueFields {
    /**
     * The total duration of the time tracker in seconds.
     */
    duration?: boolean;
    /**
     * The column's history.
     */
    history?: {
        fields: TimeTrackingHistoryItemFields;
    };
    /**
     * Returns true if the time tracker is currently running.
     */
    running?: boolean;
    /**
     * The date the time tracker started.
     */
    started_at?: boolean;
    /**
     * The column's last updated date.
     */
    updated_at?: boolean;
}
export interface TimeTrackingValueReturnType extends ColumnReturnType {
    /**
     * The total duration of the time tracker in seconds.
     */
    duration?: number | null;
    /**
     * The column's history.
     */
    history?: TimeTrackingHistoryItemReturnType[] | null;
    /**
     * Returns true if the time tracker is currently running.
     */
    running?: boolean | null;
    /**
     * The date the time tracker started.
     */
    started_at?: string | null;
    /**
     * The column's last updated date.
     */
    updated_at?: string | null;
}
export declare type SelectTimeTrackingHistoryItemReturnType<S extends TimeTrackingHistoryItemFields> = {
    [P in keyof S]: P extends keyof TimeTrackingHistoryItemReturnType ? TimeTrackingHistoryItemReturnType[P] : TimeTrackingHistoryItemReturnType;
};
export interface TimeTrackingHistoryItemFields extends OperationFields {
    /**
     * The date the session was added to the item.
     */
    created_at?: boolean;
    /**
     * The date the session ended.
     */
    ended_at?: boolean;
    /**
     * The unique identifier of the user that ended the time tracking.
     */
    ended_user_id?: boolean;
    /**
     * The unique session identifier.
     */
    id?: boolean;
    /**
     * Returns true if the session end date was manually entered.
     */
    manually_entered_end_date?: boolean;
    /**
     * Returns true if the session end time was manually entered.
     */
    manually_entered_end_time?: boolean;
    /**
     * Returns true if the session start date was manually entered.
     */
    manually_entered_start_date?: boolean;
    /**
     * Returns true if the session start time was manually entered.
     */
    manually_entered_start_time?: boolean;
    /**
     * The date the session was started. Only applicable if the session was started by pressing the play button or through an automation.
     */
    started_at?: boolean;
    /**
     * The unique identifier of the user that started the time tracking.
     */
    started_user_id?: boolean;
    /**
     * The session's status.
     */
    status?: boolean;
    /**
     * The date the session was updated.
     */
    updated_at?: boolean;
}
export interface TimeTrackingHistoryItemReturnType {
    /**
     * The date the session was added to the item.
     */
    created_at?: string | null;
    /**
     * The date the session ended.
     */
    ended_at?: string | null;
    /**
     * The unique identifier of the user that ended the time tracking.
     */
    ended_user_id?: number | null;
    /**
     * The unique session identifier.
     */
    id?: number | null;
    /**
     * Returns true if the session end date was manually entered.
     */
    manually_entered_end_date?: boolean | null;
    /**
     * Returns true if the session end time was manually entered.
     */
    manually_entered_end_time?: boolean | null;
    /**
     * Returns true if the session start date was manually entered.
     */
    manually_entered_start_date?: boolean | null;
    /**
     * Returns true if the session start time was manually entered.
     */
    manually_entered_start_time?: boolean | null;
    /**
     * The date the session was started. Only applicable if the session was started by pressing the play button or through an automation.
     */
    started_at?: string | null;
    /**
     * The unique identifier of the user that started the time tracking.
     */
    started_user_id?: number | null;
    /**
     * The session's status.
     */
    status?: string | null;
    /**
     * The date the session was updated.
     */
    updated_at?: string | null;
}
//# sourceMappingURL=timeTrackingValue.d.ts.map