/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ID } from '../types/id';
import { DocBlockFields, DocBlockReturnType, SelectDocBlockReturnType } from './docBlock';
import { OperationFields } from './typeOptions';
import { SelectUserReturnType, UserFields, UserReturnType } from './user';
import { SelectWorkspaceReturnType, WorkspaceFields, WorkspaceReturnType } from './workspace';
export declare type SelectDocsReturnType<S extends DocsFields> = {
    [P in keyof S]: P extends 'blocks' ? Array<SelectDocBlockReturnType<NonNullable<S['blocks']>['fields']>> : P extends 'created_by' ? Array<SelectUserReturnType<NonNullable<S['created_by']>['fields']>> : P extends 'workspace' ? Array<SelectWorkspaceReturnType<NonNullable<S['workspace']>['fields']>> : P extends keyof DocsReturnType ? DocsReturnType[P] : DocsReturnType;
};
export interface DocsFields extends OperationFields {
    /**
     * The document's content blocks.
     */
    blocks?: {
        args?: {
            /**
             * The number of docs to get. The default is 25.
             */
            limit?: number;
            /**
             * The page number to return. Starts at 1.
             */
            page?: number;
        };
        fields: DocBlockFields;
    };
    /**
     * The document's creation date.
     */
    created_at?: boolean;
    /**
     * The document's creator.
     */
    created_by?: {
        fields: UserFields;
    };
    /**
     * The unique identifier of the folder that contains the doc. Returns null for the first level.
     */
    doc_folder_id?: boolean;
    /**
     * The document's kind: public, private, or share.
     */
    doc_kind?: boolean;
    /**
     * The document's unique identifier.
     */
    id?: boolean;
    /**
     * The document's name.
     */
    name?: boolean;
    /**
     * The associated board or object's unique identifier. This is the same ID in the URL and the doc column values.
     */
    object_id?: boolean;
    /**
     * The document's relative URL.
     */
    relative_url?: boolean;
    /**
     * The document's direct URL.
     */
    url?: boolean;
    /**
     * The workspace that contains this document. Returns null for the Main workspace.
     */
    workspace?: {
        fields: WorkspaceFields;
    };
    /**
     * The unique identifier of the workspace that contains the doc. Returns null for the Main workspace.
     */
    workspace_id?: boolean;
    /**
     * The document's settings.
     */
    settings?: boolean;
}
export interface DocsReturnType {
    /**
     * The document's content blocks.
     */
    blocks: DocBlockReturnType[] | null;
    /**
     * The document's creation date.
     */
    created_at: string | null;
    /**
     * The document's creator.
     */
    created_by: UserReturnType | null;
    /**
     * The unique identifier of the folder that contains the doc. Returns null for the first level.
     */
    doc_folder_id: ID | null;
    /**
     * The document's kind: public, private, or share.
     */
    doc_kind: 'public' | 'private' | 'share' | null;
    /**
     * The document's unique identifier.
     */
    id: ID | null;
    /**
     * The document's name.
     */
    name: string | null;
    /**
     * The associated board or object's unique identifier. This is the same ID in the URL and the doc column values.
     */
    object_id: ID | null;
    /**
     * The document's relative URL.
     */
    relative_url: string | null;
    /**
     * The document's direct URL.
     */
    url: string | null;
    /**
     * The workspace that contains this document. Returns null for the Main workspace.
     */
    workspace: WorkspaceReturnType | null;
    /**
     * The unique identifier of the workspace that contains the doc. Returns null for the Main workspace.
     */
    workspace_id: ID | null;
    /**
     * The document's settings.
     */
    settings: JSON | null;
}
//# sourceMappingURL=doc.d.ts.map