import { SelectItemReturnType } from './item';
import { ItemsPageArgs, ItemsPageFields, ItemsPageReturnType } from './itemsPage';
import { OperationFields } from './typeOptions';
export declare type SelectBoardGroupReturnType<S extends BoardGroupFields> = {
    [P in keyof S]: P extends 'items' ? Array<SelectItemReturnType<NonNullable<NonNullable<S['items_page']>['fields']['items']>['fields']>> : P extends keyof BoardGroupReturnType ? BoardGroupReturnType[P] : BoardGroupReturnType;
};
export interface BoardGroupFields extends OperationFields {
    archived?: boolean;
    /**
     * The group's color.
     */
    color?: boolean;
    /**
     * Is the group deleted or not.
     */
    deleted?: boolean;
    /**
     * The group's unique identifier.
     */
    id?: boolean;
    /**
     * The items in the group.
     */
    items_page?: {
        args?: ItemsPageArgs;
        fields: ItemsPageFields;
    };
    /**
     * The group's position in the board.
     */
    position?: boolean;
    /**
     * The group's title.
     */
    title?: boolean;
}
export interface BoardGroupReturnType {
    /**
     * Is the group archived or not.
     */
    archived: boolean | null;
    /**
     * The group's color.
     */
    color: string;
    /**
     * Is the group deleted or not.
     */
    deleted: boolean | null;
    /**
     * The group's unique identifier.
     */
    id: string;
    /**
     * The items page that contains the items.
     */
    items_page: null | ItemsPageReturnType;
    /**
     * The group's position in the board.
     */
    position: string;
    /**
     * The group's title.
     */
    title: string;
}
export declare type PositionRelative = 'before_at' | 'after_at';
export declare type GroupAttributes = 'relative_position_before' | 'relative_position_after' | 'title' | 'color';
/**
 * A list of valid group colors that can be used to update a group color
 * extracted from : https://dapulse-res.cloudinary.com/image/upload/v1669754611/remote_mondaycom_static/developers/screenshots/status-labels-2.png
 */
export declare type GroupColors = 'dark-green' | 'orange' | 'blue' | 'red' | 'green' | 'grey' | 'dark-blue' | 'purple' | 'yellow' | 'lime-green' | 'brown' | 'dark-red' | 'trolley-grey' | 'dark-purple' | 'dark-orange' | 'dark-pink' | 'turquoise' | 'light-pink';
export declare enum GroupColorHexCodes {
    LIGHT_PINK = "#FF5AC4",
    DARK_PINK = "#FF158A",
    DARK_RED = "#BB3354",
    RED = "#e2445c",
    DARK_ORANGE = "#FF642E",
    ORANGE = "#fdab3d",
    YELLOW = "#FFCB00",
    MUSTARD_YELLOW = "#CAB641",
    LIME_GREEN = "#9CD326",
    GREEN = "#00c875",
    DARK_GREEN = "#037f4c",
    DARK_BLUE = "#0086c0",
    BLUE = "#579bfc",
    TURQUOISE = "#66CCFF",
    PURPLE = "#a25ddc",
    DARK_PURPLE = "#784BD1",
    BROWN = "#7F5347",
    GREY = "#c4c4c4",
    TROLLEY_GREY = "#808080"
}
//# sourceMappingURL=group.d.ts.map