import { AssetReturnType, AssetFields } from './asset';
import { BoardReturnType, BoardFields } from './board';
import { ColumnValueReturnType, ColumnValueFields, SelectColumnValueReturnType } from './columnValue';
import { BoardGroupReturnType, BoardGroupFields, SelectBoardGroupReturnType } from './group';
import { OperationFields } from './typeOptions';
import { UpdateFields, UpdateReturnType } from './update';
import { UserFields, UserReturnType } from './user';
import { SelectAssetReturnType } from './asset';
import { SelectBoardReturnType } from './board';
import { SelectUpdateReturnType } from './update';
import { SelectUserReturnType } from './user';
import { StatusValueFields } from './columnValueFragments/statusValue';
import { TimelineValueFields } from './columnValueFragments/timelineValue';
import { BoardRelationValueFields } from './columnValueFragments/boardRelationValue';
import { ButtonValueFields } from './columnValueFragments/buttonValue';
import { CheckboxValueFields } from './columnValueFragments/checkboxValue';
import { ColorPickerValueFields } from './columnValueFragments/colorPickerValue';
import { CountryValueFields } from './columnValueFragments/countryValue';
import { CreationLogValueFields } from './columnValueFragments/creationLogValue';
import { DateValueFields } from './columnValueFragments/dateValue';
import { DependencyValueFields } from './columnValueFragments/dependencyValue';
import { DocValueFields } from './columnValueFragments/docValue';
import { DropdownValueFields } from './columnValueFragments/dropdownValue';
import { EmailValueFields } from './columnValueFragments/emailValue';
import { FileValueFields } from './columnValueFragments/fileValue';
import { FormulaValueFields } from './columnValueFragments/formulaValue';
import { HourValueFields } from './columnValueFragments/hourValue';
import { LongTextValueFields } from './columnValueFragments/longTextValue';
import { ItemIdValueFields } from './columnValueFragments/itemIdValue';
import { LastUpdatedValueFields } from './columnValueFragments/lastUpdatedValue';
import { LinkValueFields } from './columnValueFragments/linkValue';
import { LocationValueFields } from './columnValueFragments/locationValue';
import { MirrorValueFields } from './columnValueFragments/mirrorValue';
import { NumbersValueFields } from './columnValueFragments/numbersValue';
import { PeopleValueFields } from './columnValueFragments/peopleValue';
import { PhoneValueFields } from './columnValueFragments/phoneValue';
import { RatingValueFields } from './columnValueFragments/ratingValue';
import { TagsValueFields } from './columnValueFragments/tagsValue';
import { TextValueFields } from './columnValueFragments/textValue';
import { TimeTrackingValueFields } from './columnValueFragments/timeTrackingValue';
import { VoteValueFields } from './columnValueFragments/voteValue';
import { WeekValueFields } from './columnValueFragments/weekValue';
import { WorldClockValueFields } from './columnValueFragments/worldClockValue';
export declare type SelectItemReturnType<S extends ItemFields> = {
    [P in keyof S]: P extends 'assets' ? Array<SelectAssetReturnType<NonNullable<S['assets']>['fields']>> : P extends 'board' ? SelectBoardReturnType<NonNullable<S['board']>['fields']> : P extends 'column_values' ? Array<SelectColumnValueReturnType<NonNullable<S['column_values']>['fields']>> : P extends 'creator' ? SelectUserReturnType<NonNullable<S['creator']>['fields']> : P extends 'group' ? SelectBoardGroupReturnType<NonNullable<S['group']>['fields']> : P extends 'subitems' ? Array<SelectItemReturnType<NonNullable<S['subitems']>['fields']>> : P extends 'subscribers' ? Array<SelectUserReturnType<NonNullable<S['subscribers']>['fields']>> : P extends 'updates' ? Array<SelectUpdateReturnType<NonNullable<S['updates']>['fields']>> : P extends keyof ItemReturnType ? ItemReturnType[P] : ItemReturnType;
};
export interface ItemFields extends OperationFields {
    /**
     * The item's assets/files.
     */
    assets?: {
        args?: {
            /**
             * The assets source (all / columns / gallery)
             */
            assets_source?: 'all' | 'columns' | 'gallery';
            /**
             * Ids of the columns you want to get assets from.
             */
            column_ids?: string[];
        };
        fields: AssetFields;
    };
    /**
     * The board that contains this item.
     */
    board?: {
        fields: BoardFields;
    };
    /**
     * The item's column values.
     */
    column_values?: {
        args?: {
            /**
             * A list of column ids to return
             */
            ids?: string[];
        };
        fields: ColumnValueFields;
        fragments?: {
            /**
             * Column values specific to connect board columns.
             */
            BoardRelationValue?: BoardRelationValueFields;
            /**
             * Column values specific to button columns.
             */
            ButtonValue?: ButtonValueFields;
            /**
             * Column values specific to checkbox columns.
             */
            CheckboxValue?: CheckboxValueFields;
            /**
             * Column values specific to color picker columns.
             */
            ColorPickerValue?: ColorPickerValueFields;
            /**
             * Column values specific to country columns.
             */
            CountryValue?: CountryValueFields;
            /**
             * Column values specific to creation log columns.
             */
            CreationLogValue?: CreationLogValueFields;
            /**
             * Column values specific to date columns.
             */
            DateValue?: DateValueFields;
            /**
             * Column values specific to dependency columns.
             */
            DependencyValue?: DependencyValueFields;
            /**
             * Column values specific to monday doc columns.
             */
            DocValue?: DocValueFields;
            /**
             * Column values specific to dropdown columns.
             */
            DropdownValue?: DropdownValueFields;
            /**
             * Column values specific to email columns.
             */
            EmailValue?: EmailValueFields;
            /**
             * Column values specific to file columns.
             */
            FileValue?: FileValueFields;
            /**
             * Column values specific to formula columns.
             */
            FormulaValue?: FormulaValueFields;
            /**
             * Column values specific to hour columns.
             */
            HourValue?: HourValueFields;
            /**
             * Column values specific to item ID columns.
             */
            ItemIdValue?: ItemIdValueFields;
            /**
             * Column values specific to last updated columns.
             */
            LastUpdatedValue?: LastUpdatedValueFields;
            /**
             * Column values specific to link columns.
             */
            LinkValue?: LinkValueFields;
            /**
             * Column values specific to location columns.
             */
            LocationValue?: LocationValueFields;
            /**
             * Column values specific to long text columns.
             */
            LongTextValue?: LongTextValueFields;
            /**
             * Column values specific to mirror columns.
             */
            MirrorValue?: MirrorValueFields;
            /**
             * Column values specific to number columns.
             */
            NumbersValue?: NumbersValueFields;
            /**
             * Column values specific to people columns.
             */
            PeopleValue?: PeopleValueFields;
            /**
             * Column values specific to phone columns.
             */
            PhoneValue?: PhoneValueFields;
            /**
             * Column values specific to rating columns.
             */
            RatingValue?: RatingValueFields;
            /**
             * Column values specific to status columns.
             */
            StatusValue?: StatusValueFields;
            /**
             * Column values specific to tag columns.
             */
            TagsValue?: TagsValueFields;
            /**
             * Column values specific to text columns.
             */
            TextValue?: TextValueFields;
            /**
             * Column values specific to timeline columns.
             */
            TimelineValue?: TimelineValueFields;
            /**
             * Column values specific to time tracking columns.
             */
            TimeTrackingValue?: TimeTrackingValueFields;
            /**
             * Column values specific to vote columns.
             */
            VoteValue?: VoteValueFields;
            /**
             * Column values specific to week columns.
             */
            WeekValue?: WeekValueFields;
            /**
             * Column values specific to world clock columns.
             */
            WorldClockValue?: WorldClockValueFields;
        };
    };
    /**
     * The item's create date.
     */
    created_at?: boolean;
    /**
     * The item's creator.
     */
    creator?: {
        fields: UserFields;
    };
    /**
     * The unique identifier of the item creator.
     */
    creator_id?: boolean;
    /**
     * The item's email.
     */
    email?: boolean;
    /**
     * The group that contains this item.
     */
    group?: {
        fields: BoardGroupFields;
    };
    /**
     * The item's unique identifier.
     */
    id?: boolean;
    /**
     * The item's name.
     */
    name?: boolean;
    /**
     * The parent item of a subitem.
     */
    parent_item?: {
        fields: ItemFields;
    };
    /**
     * The item's relative path
     */
    relative_link?: boolean;
    /**
     * The item's state (all / active / archived / deleted).
     */
    state?: boolean;
    /**
     * The item's subitems.
     */
    subitems?: {
        fields: ItemFields;
    };
    /**
     * The pulses's subscribers.
     */
    subscribers?: {
        fields: UserFields;
    };
    /**
     * The item's last update date.
     */
    updated_at?: boolean;
    /**
     * The item's updates.
     */
    updates?: {
        args?: {
            /**
             * The specific ID(s) to return updates for.
             */
            ids?: number[];
            /**
             * Number of items to get, the default is 25.
             */
            limit?: number;
            /**
             * Page number to get, starting at 1.
             */
            page?: number;
        };
        fields: UpdateFields;
    };
    /**
     * The item's URL.
     */
    url?: boolean;
}
export interface ItemReturnType {
    /**
     * The item's assets/files.
     */
    assets: AssetReturnType[] | null;
    /**
     * The board that contains this item.
     */
    board: BoardReturnType | null;
    /**
     * The item's column values.
     */
    column_values: ColumnValueReturnType[] | null;
    /**
     * The item's create date.
     */
    created_at: string | null;
    /**
     * The item's creator.
     */
    creator: UserReturnType | null;
    /**
     * The unique identifier of the item creator.
     */
    creator_id: string;
    /**
     * The item's email.
     */
    email: string;
    /**
     * The group that contains this item.
     */
    group: BoardGroupReturnType | null;
    /**
     * The item's unique identifier.
     */
    id: string;
    /**
     * The item's name.
     */
    name: string;
    /**
     * The parent item of a subitem.
     */
    parent_item: ItemReturnType | null;
    /**
     * The item's relative path
     */
    relative_link: string | null;
    /**
     * The item's state (all / active / archived / deleted).
     */
    state: 'all' | 'active' | 'archived' | 'deleted' | null;
    /**
     * The item's subitems.
     */
    subitems: null | ItemReturnType[];
    /**
     * The pulses's subscribers.
     */
    subscribers: UserReturnType[];
    /**
     * The item's last update date.
     */
    updated_at: string | null;
    /**
     * The item's updates.
     */
    updates: UpdateReturnType[] | null;
    /**
     * The item's URL.
     */
    url: string | null;
}
//# sourceMappingURL=item.d.ts.map