import { OperationFields } from './typeOptions';
import { UserReturnType, UserFields, SelectUserReturnType, UserKind } from './user';
export declare type SelectTeamReturnType<S extends TeamFields> = {
    [P in keyof S]: P extends 'users' ? Array<SelectUserReturnType<NonNullable<S['users']>['fields']>> : P extends keyof TeamReturnType ? TeamReturnType[P] : TeamReturnType;
};
export interface TeamFields extends OperationFields {
    /**
     * The team's unique identifier.
     */
    id?: boolean;
    /**
     * The team's name.
     */
    name?: boolean;
    /**
     * The team's picture url.
     */
    picture_url?: boolean;
    /**
     * The users in the team.
     */
    users?: {
        args?: {
            /**
             * A list of users' unique identifiers.
             */
            ids?: number[];
            /**
             *  The kind to search users by (all / non_guests / guests / non_pending).
             */
            kind?: UserKind;
            /**
             * Get the recently created users at the top of the list
             */
            newest_first?: boolean;
            /**
             * A list of users' emails.
             */
            emails?: string[];
            /**
             * Allows to fuzzy search by name
             */
            name?: string;
            /**
             * Return non active users in the account.
             */
            non_active?: boolean;
            /**
             * Number of users to get.
             */
            limit?: number;
            /**
             * Page number to get, starting at 1.
             */
            page?: number;
        };
        fields: UserFields;
    };
}
export interface TeamReturnType {
    /**
     * The team's unique identifier.
     */
    id: number;
    /**
     * The team's name.
     */
    name: string;
    /**
     * The team's picture url.
     */
    picture_url: string | null;
    /**
     * The users in the team.
     */
    users: null | UserReturnType[];
}
export declare type SelectChangeTeamMembershipResultReturnType<S extends ChangeTeamMembershipResultFields> = {
    [P in keyof S]: P extends 'successful_users' ? Array<SelectTeamReturnType<NonNullable<S['successful_users']>['fields']>> : P extends 'failed_users' ? Array<SelectTeamReturnType<NonNullable<S['failed_users']>['fields']>> : P extends keyof ChangeTeamMembershipResultReturnType ? ChangeTeamMembershipResultReturnType[P] : ChangeTeamMembershipResultReturnType;
};
export interface ChangeTeamMembershipResultFields extends OperationFields {
    /**
     * Users succesfully moved team.
     */
    successful_users?: {
        fields: TeamFields;
    };
    /**
     * Users failed to move team.
     */
    failed_users?: {
        fields: TeamFields;
    };
}
export interface ChangeTeamMembershipResultReturnType {
    /**
     * Users succesfully moved team.
     */
    successful_users?: TeamReturnType[] | null;
    /**
     * Users failed to move team.
     */
    failed_users?: TeamReturnType[] | null;
}
//# sourceMappingURL=team.d.ts.map