export function getVersion() {
    return '2024-01';
}
export const MethodTypeOptions = {
    boards: {
        args: {
            ids: { type: 'ID!' },
            board_kind: { type: 'BoardKind' },
            order_by: { type: 'BoardsOrderBy' },
            state: { type: 'State' },
            workspace_ids: { type: 'ID!' }
        },
        fields: 'board',
    },
    create_update: {
        args: {
            body: { required: true },
            item_id: { type: 'ID' },
            parent_id: { type: 'ID' },
        },
        fields: 'update'
    },
    delete_update: {
        args: {
            id: { type: 'ID', required: true },
        },
        fields: 'update'
    },
    like_update: {
        args: {
            update_id: { type: 'ID' },
        },
        fields: 'update'
    },
    add_teams_to_board: {
        args: {
            team_ids: { type: 'ID!', required: true },
            board_id: { type: 'ID', required: true }
        },
        fields: 'team'
    },
    add_teams_to_workspace: {
        args: {
            team_ids: { type: 'ID!', required: true },
            workspace_id: { type: 'ID', required: true },
            kind: { type: 'WorkspaceSubscriberKind' }
        },
        fields: 'team'
    },
    delete_teams_from_workspace: {
        args: {
            team_ids: { type: 'ID!', required: true },
            workspace_id: { type: 'ID', required: true }
        },
        fields: 'team'
    },
    delete_teams_from_board: {
        args: {
            team_ids: { type: 'ID!', required: true },
            board_id: { type: 'ID', required: true }
        },
        fields: 'team'
    },
    add_users_to_team: {
        args: {
            user_ids: { type: 'ID!', required: true },
            team_id: { type: 'ID', required: true }
        },
        fields: 'team'
    },
    remove_users_from_team: {
        args: {
            user_ids: { type: 'ID!', required: true },
            team_id: { type: 'ID', required: true }
        },
        fields: 'team'
    },
    teams: {
        args: {
            ids: { type: 'ID!' }
        },
        fields: 'team'
    },
    items: {
        args: {
            ids: { type: 'ID!', required: true },
        },
        fields: 'item'
    },
    create_item: {
        args: {
            board_id: { type: 'ID', required: true },
            item_name: { type: 'String!', required: false },
            column_values: { type: 'JSON' },
        },
        fields: 'item'
    },
    duplicate_item: {
        args: {
            item_id: { type: 'ID', required: true },
            board_id: { type: 'ID', required: true },
        },
        fields: 'item'
    },
    move_item_to_group: {
        args: {
            item_id: { type: 'ID' },
            group_id: { required: true },
        },
        fields: 'item'
    },
    clear_item_updates: {
        args: {
            item_id: { type: 'ID', required: true },
        },
        fields: 'item'
    },
    archive_item: {
        args: {
            item_id: { type: 'ID', required: true }
        },
        fields: 'item'
    },
    delete_item: {
        args: {
            item_id: { type: 'ID', required: true }
        },
        fields: 'item'
    },
    move_item_to_board: {
        args: {
            board_id: { type: 'ID', required: true },
            item_id: { type: 'ID', required: true },
            group_id: { type: 'ID', required: true },
            columns_mapping: { type: 'ColumnMappingInput!' },
            subitems_column_mapping: { type: 'ColumnMappingInput!' },
        },
        fields: 'item'
    },
    create_board: {
        args: {
            board_name: { required: true },
            board_kind: { type: 'BoardKind', required: true },
            board_owner_ids: { type: 'ID!' },
            board_subscriber_ids: { type: 'ID!' },
            board_subscriber_teams_ids: { type: 'ID!' },
            folder_id: { type: 'ID' },
            template_id: { type: 'ID' },
            workspace_id: { type: 'ID' }
        },
        fields: 'board'
    },
    duplicate_board: {
        args: {
            board_id: { type: 'ID', required: true },
            duplicate_type: { type: 'DuplicateBoardType', required: true },
            workspace_id: { type: 'ID' },
            folder_id: { type: 'ID' }
        },
        fields: 'board'
    },
    archive_board: {
        args: {
            board_id: { type: 'ID', required: true },
        },
        fields: 'board'
    },
    delete_board: {
        args: {
            board_id: { type: 'ID', required: true },
        },
        fields: 'board'
    },
    delete_subscribers_from_board: {
        args: {
            board_id: { type: 'ID', required: true },
            user_ids: { type: 'ID!', required: true },
        },
        fields: 'user'
    },
    update_board: {
        args: {
            board_id: { type: 'ID', required: true },
            board_attribute: { type: 'BoardAttributes', required: true },
            new_value: { required: true },
        }
    },
    create_notification: {
        args: {
            target_type: { type: 'NotificationTargetType', required: true },
            target_id: { type: 'ID', required: true },
            text: { required: true },
            user_id: { type: 'ID', required: true }
        },
        fields: 'text'
    },
    add_users_to_board: {
        args: {
            kind: { type: 'BoardSubscriberKind' },
            board_id: { type: 'ID', required: true },
            user_ids: { type: 'ID!', required: true }
        },
        fields: 'user'
    },
    add_users_to_workspace: {
        args: {
            kind: { type: 'WorkspaceSubscriberKind' },
            workspace_id: { type: 'ID', required: true },
            user_ids: { type: 'ID!', required: true }
        },
        fields: 'user'
    },
    delete_users_from_workspace: {
        args: {
            workspace_id: { type: 'ID', required: true },
            user_ids: { type: 'ID!', required: true }
        },
        fields: 'user'
    },
    users: {
        args: {
            ids: { type: 'ID!' },
            kind: { type: 'UserKind' }
        },
        fields: 'user'
    },
    groups: {
        fields: 'group',
    },
    create_group: {
        args: {
            board_id: { type: 'ID', required: true },
            group_name: { required: true },
            position_relative_method: { type: 'PositionRelative' }
        },
        fields: 'group'
    },
    delete_group: {
        args: {
            group_id: { required: true },
            board_id: { type: 'ID', required: true }
        }
    },
    archive_group: {
        args: {
            group_id: { required: true },
            board_id: { type: 'ID', required: true }
        }
    },
    duplicate_group: {
        args: {
            board_id: { type: 'ID', required: true },
            group_id: { required: true }
        }
    },
    update_group: {
        args: {
            board_id: { type: 'ID', required: true },
            group_id: { required: true },
            new_value: { required: true },
            group_attribute: { type: 'GroupAttributes', required: true }
        }
    },
    workspaces: {
        args: {
            ids: { type: 'ID!' },
            kind: { type: 'WorkspaceKind' },
            order_by: { type: 'WorkspacesOrderBy' },
            state: { type: 'State' }
        },
        fields: 'workspace'
    },
    create_workspace: {
        args: {
            name: { required: true },
            kind: { type: 'WorkspaceKind', required: true },
        },
        fields: 'workspace'
    },
    update_workspace: {
        args: {
            id: { type: 'ID', required: true },
            attributes: { type: 'UpdateWorkspaceAttributesInput', required: true },
        },
        fields: 'workspace'
    },
    delete_workspace: {
        args: {
            workspace_id: { type: 'ID', required: true }
        },
        fields: 'workspace'
    },
    create_column: {
        args: {
            board_id: { type: 'ID', required: true },
            after_column_id: { type: 'ID' },
            title: { required: true },
            column_type: { type: 'ColumnType!' },
            defaults: { type: 'JSON' },
        },
        fields: 'column'
    },
    change_column_value: {
        args: {
            board_id: { type: 'ID', required: true },
            column_id: { required: true },
            item_id: { type: 'ID' },
            value: { type: 'JSON', required: true },
        },
        fields: 'item'
    },
    change_simple_column_value: {
        args: {
            column_id: { required: true },
            board_id: { type: 'ID', required: true },
            item_id: { type: 'ID' },
            value: { required: true },
        },
        fields: 'item'
    },
    change_multiple_column_values: {
        args: {
            board_id: { type: 'ID', required: true },
            column_values: { type: 'JSON', required: true },
            item_id: { type: 'ID', required: true }
        },
        fields: 'item'
    },
    change_column_title: {
        args: {
            column_id: { required: true },
            board_id: { type: 'ID', required: true },
            title: { required: true },
        },
        fields: 'column'
    },
    change_column_metadata: {
        args: {
            column_id: { required: true },
            board_id: { type: 'ID', required: true },
            column_property: { type: 'ColumnProperty', required: true },
        },
        fields: 'column'
    },
    delete_column: {
        args: {
            column_id: { required: true },
            board_id: { type: 'ID', required: true },
        },
        fields: 'column'
    },
    assets: {
        args: {
            ids: { type: 'ID!', required: true },
        },
        fields: 'asset'
    },
    add_file_to_update: {
        args: {
            update_id: { type: 'ID', required: true },
            file: { type: 'File', required: true }
        },
        fields: 'asset'
    },
    add_file_to_column: {
        args: {
            item_id: { type: 'ID', required: true },
            column_id: { required: true },
            file: { type: 'File', required: true }
        },
        fields: 'asset'
    },
    create_subitem: {
        args: {
            item_name: { required: true },
            parent_item_id: { type: 'ID', required: true },
            column_values: { type: 'JSON' }
        },
        fields: 'item'
    },
    items_page: {
        args: {
            query_params: { type: 'ItemsQuery' },
        },
        fields: 'item'
    },
    next_items_page: {
        args: {
            cursor: { type: 'String', required: true },
            limit: { type: 'Int', required: true },
        },
        fields: 'item'
    },
    items_page_by_column_values: {
        args: {
            board_id: { type: 'ID', required: true },
            cursor: { type: 'String', required: true },
            limit: { type: 'Int', required: true },
            columns: { type: 'ItemsPageByColumnValuesQuery!', required: true }
        },
        fields: 'items_page'
    },
    docs: {
        args: {
            ids: { type: 'ID!' },
            object_ids: { type: 'ID!' },
            workspace_ids: { type: 'ID' },
            order_by: { type: 'DocsOrderBy' },
        },
        fields: 'doc'
    },
    create_doc: {
        args: {
            location: { type: 'CreateDocInput', required: true },
        },
        fields: 'doc'
    },
    create_doc_block: {
        args: {
            doc_id: { type: 'ID', required: true },
            content: { type: 'JSON', required: true },
            type: { type: 'DocBlockContentType', required: true },
        },
        fields: 'block'
    },
    update_doc_block: {
        args: {
            block_id: { type: 'String', required: true },
            content: { type: 'JSON', required: true },
        },
        fields: 'block'
    },
    delete_doc_block: {
        args: {
            block_id: { type: 'String', required: true },
        },
        fields: 'block'
    },
    tags: {
        args: {
            ids: { type: 'ID!' },
        },
        fields: 'item'
    },
    create_or_get_tag: {
        args: {
            board_id: { type: 'ID' },
        },
        fields: 'item'
    },
    webhooks: {
        args: {
            board_id: { type: 'ID', required: true }
        },
        fields: 'webhook'
    },
    create_webhook: {
        args: {
            board_id: { type: 'ID', required: true },
            config: { type: 'JSON' },
            event: { type: 'WebhookEventType', required: true },
            url: { required: true }
        },
        fields: 'webhook'
    },
    delete_webhook: {
        args: {
            id: { type: 'ID', required: true },
        },
        fields: 'webhook'
    },
    folders: {
        args: {
            ids: { type: 'ID!', },
            workspace_ids: { type: 'ID' },
        },
        fields: 'folder'
    },
    create_folder: {
        args: {
            name: { type: 'String', required: true },
            color: { type: 'FolderColor' },
            workspace_id: { type: 'ID' },
        },
        fields: 'folder'
    },
    update_folder: {
        args: {
            folder_id: { type: 'ID', required: true },
            color: { type: 'FolderColor' },
            parent_folder_id: { type: 'ID' },
        },
        fields: 'folder'
    },
    delete_folder: {
        args: {
            folder_id: { type: 'ID', required: true },
        },
        fields: 'folder'
    },
    updates: {
        args: {
            ids: { type: 'ID!' },
        },
        fields: 'update',
    },
};
export const FieldTypeOptions = {
    board: {
        activity_logs: {
            args: {
                from: { type: 'ISO8601DateTime' },
                to: { type: 'ISO8601DateTime' },
            },
        },
        creator: {
            fields: 'user',
        },
        groups: {
            fields: 'group',
        },
        items: {
            fields: 'item',
        },
        items_page: {
            args: {
                query_params: { type: 'ItemsQuery' },
            },
            fields: 'items_page',
        },
        owners: {
            fields: 'user',
        },
        subscribers: {
            fields: 'user',
        },
        top_group: {
            fields: 'group',
        },
        updates: {
            args: {
                ids: { type: 'ID!' },
            },
            fields: 'update',
        },
        workspace: {
            fields: 'workspace',
        },
        views: {
            args: {
                ids: { type: 'ID!' },
            },
            fields: 'view'
        }
    },
    user: {
        teams: {
            fields: 'team',
        },
    },
    team: {
        users: {
            args: {
                kind: { type: 'UserKind' },
            },
            fields: 'user',
        },
    },
    group: {
        items_page: {
            args: {
                query_params: { type: 'ItemsQuery' },
            },
            fields: 'items_page',
        }
    },
    items_page: {
        items: {
            fields: 'item',
        }
    },
    item: {
        assets: {
            args: {
                assets_source: { type: 'AssetsSource' },
            },
            fields: 'asset',
        },
        board: {
            fields: 'board',
        },
        column_values: {
            args: {
                ids: { type: 'String!' }
            },
            fields: 'column_value',
        },
        creator: {
            fields: 'user',
        },
        group: {
            fields: 'group',
        },
        parent_item: {
            fields: 'item',
        },
        subitems: {
            fields: 'item',
        },
        subscribers: {
            fields: 'user',
        },
        updates: {
            args: {
                ids: { type: 'ID!' },
            },
            fields: 'update',
        },
    },
    asset: {
        uploaded_by: {
            fields: 'user',
        }
    },
    update: {
        assets: {
            fields: 'asset',
        },
        creator: {
            fields: 'user',
        },
        replies: {
            fields: 'reply',
        },
    },
    reply: {
        creator: {
            fields: 'user',
        }
    },
    workspace: {
        owners_subscribers: {
            fields: 'user',
        },
        team_owners_subscribers: {
            fields: 'team',
        },
        teams_subscribers: {
            fields: 'team',
        },
        users_subscribers: {
            fields: 'user',
        },
    },
};
