import { AccountReturnType, AccountFields } from './account';
import { OutOfOfficeFields, OutOfOfficeReturnType } from './outOfOffice';
import { TeamFields, TeamReturnType } from './team';
import { OperationFields } from './typeOptions';
import { SelectAccountReturnType } from './account';
import { SelectOutOfOfficeReturnType } from './outOfOffice';
import { SelectTeamReturnType } from './team';
export declare type SelectUserReturnType<S extends UserFields> = {
    [P in keyof S]: P extends 'account' ? SelectAccountReturnType<NonNullable<S['account']>['fields']> : P extends 'out_of_office' ? SelectOutOfOfficeReturnType<NonNullable<S['out_of_office']>['fields']> : P extends 'teams' ? Array<SelectTeamReturnType<NonNullable<S['teams']>['fields']>> : P extends keyof UserReturnType ? UserReturnType[P] : UserReturnType;
};
export interface UserFields extends OperationFields {
    /**
     * The user's account.
     */
    account?: {
        fields: AccountFields;
    };
    /**
     * The user's birthday.
     */
    birthday?: boolean;
    /**
     * The user's country code.
     */
    country_code?: boolean;
    /**
     * The user's creation date.
     */
    created_at?: boolean;
    /**
     * The current user's language
     */
    current_language?: boolean;
    /**
     * The user's email.
     */
    email?: boolean;
    /**
     * Is the user enabled or not.
     */
    enabled?: boolean;
    /**
     * The user's unique identifier.
     */
    id?: boolean;
    /**
     * Is the user an account admin.
     */
    is_admin?: boolean;
    /**
     * Is the user a guest or not.
     */
    is_guest?: boolean;
    /**
     * Is the user a pending user
     */
    is_pending?: boolean;
    /**
     * Is user verified his email.
     */
    is_verified?: boolean;
    /**
     * Is the user a view only user or not.
     */
    is_view_only?: boolean;
    /**
     * The date the user joined the account.
     */
    join_date?: boolean;
    /**
     * Last date & time when user was active
     */
    last_activity?: boolean;
    /**
     * The user's location.
     */
    location?: boolean;
    /**
     * The user's mobile phone number.
     */
    mobile_phone?: boolean;
    /**
     * The user's name.
     */
    name?: boolean;
    /**
     * The user's out of office status.
     */
    out_of_office?: {
        fields: OutOfOfficeFields;
    };
    /**
     * The user's phone number.
     */
    phone?: boolean;
    /**
     * The user's photo in the original size.
     */
    photo_original?: boolean;
    /**
     * The user's photo in small size (150x150).
     */
    photo_small?: boolean;
    /**
     * The user's photo in thumbnail size (100x100).
     */
    photo_thumb?: boolean;
    /**
     * The user's photo in small thumbnail size (50x50).
     */
    photo_thumb_small?: boolean;
    /**
     * The user's photo in tiny size (30x30).
     */
    photo_tiny?: boolean;
    /**
     * The product to which the user signed up to first.
     */
    sign_up_product_kind?: boolean;
    /**
     * The teams the user is a member in.
     */
    teams?: {
        args?: {
            /**
             * A list of teams unique identifiers.
             */
            ids?: number[];
        };
        fields: TeamFields;
    };
    /**
     * The user's timezone identifier.
     */
    time_zone_identifier?: boolean;
    /**
     * The user's title.
     */
    title?: boolean;
    /**
     * The user's profile url.
     */
    url?: boolean;
    /**
     * The user’s utc hours difference.
     */
    utc_hours_diff?: boolean;
}
export interface UserReturnType {
    /**
     * The user's account.
     */
    account: AccountReturnType;
    /**
     * The user's birthday.
     */
    birthday: string | null;
    /**
     * The user's country code.
     */
    country_code: string | null;
    /**
     * The user's creation date.
     */
    created_at: string | null;
    /**
     * The current user's language
     */
    current_language: string | null;
    /**
     * The user's email.
     */
    email: string;
    /**
     * Is the user enabled or not.
     */
    enabled: boolean;
    /**
     * The user's unique identifier.
     */
    id: number;
    /**
     * Is the user an account admin.
     */
    is_admin: boolean | null;
    /**
     * Is the user a guest or not.
     */
    is_guest: boolean | null;
    /**
     * Is the user a pending user
     */
    is_pending: boolean | null;
    /**
     * Is user verified his email.
     */
    is_verified: boolean | null;
    /**
     * Is the user a view only user or not.
     */
    is_view_only: boolean | null;
    /**
     * The date the user joined the account.
     */
    join_date: string | null;
    /**
     * Last date & time when user was active
     */
    last_activity: string | null;
    /**
     * The user's location.
     */
    location: string | null;
    /**
     * The user's mobile phone number.
     */
    mobile_phone: string | null;
    /**
     * The user's name.
     */
    name: string;
    /**
     * The user's out of office status.
     */
    out_of_office: OutOfOfficeReturnType | null;
    /**
     * The user's phone number.
     */
    phone: string | null;
    /**
     * The user's photo in the original size.
     */
    photo_original: string | null;
    /**
     * The user's photo in small size (150x150).
     */
    photo_small: string | null;
    /**
     * The user's photo in thumbnail size (100x100).
     */
    photo_thumb: string | null;
    /**
     * The user's photo in small thumbnail size (50x50).
     */
    photo_thumb_small: string | null;
    /**
     * The user's photo in tiny size (30x30).
     */
    photo_tiny: string | null;
    /**
     * The product to which the user signed up to first.
     */
    sign_up_product_kind: string | null;
    /**
     * The teams the user is a member in.
     */
    teams: TeamReturnType[] | null;
    /**
     * The user's timezone identifier.
     */
    time_zone_identifier: string | null;
    /**
     * The user's title.
     */
    title: string | null;
    /**
     * The user's profile url.
     */
    url: string;
    /**
     * The user’s utc hours difference.
     */
    utc_hours_diff: number | null;
}
export declare type UserKind = 'all' | 'non_guests' | 'guests' | 'non_pending';
//# sourceMappingURL=user.d.ts.map