import { AccountProductFields, AccountProductReturnType } from './accountProduct';
import { TeamFields, TeamReturnType } from './team';
import { OperationFields } from './typeOptions';
import { UserFields, UserReturnType } from './user';
import { WorkspaceSettingsFields, WorkspaceSettingsReturnType } from './workspaceSettings';
import { SelectUserReturnType } from './user';
import { SelectTeamReturnType } from './team';
import { SelectAccountProductReturnType } from './accountProduct';
import { SelectWorkspaceSettingsReturnType } from './workspaceSettings';
export declare type SelectWorkspaceReturnType<S extends WorkspaceFields> = {
    [P in keyof S]: P extends 'account_product' ? SelectAccountProductReturnType<NonNullable<S['account_product']>['fields']> : P extends 'owners_subscribers' ? Array<SelectUserReturnType<NonNullable<S['owners_subscribers']>['fields']>> : P extends 'settings' ? SelectWorkspaceSettingsReturnType<NonNullable<S['settings']>['fields']> : P extends 'team_owners_subscribers' ? Array<SelectTeamReturnType<NonNullable<S['team_owners_subscribers']>['fields']>> : P extends 'teams_subscribers' ? Array<SelectTeamReturnType<NonNullable<S['teams_subscribers']>['fields']>> : P extends 'users_subscribers' ? Array<SelectUserReturnType<NonNullable<S['users_subscribers']>['fields']>> : P extends keyof WorkspaceReturnType ? WorkspaceReturnType[P] : WorkspaceReturnType;
};
export interface WorkspaceFields extends OperationFields {
    /**
     * The account product that contains workspace.
     */
    account_product?: {
        fields: AccountProductFields;
    };
    /**
     * The workspace's creation date.
     */
    created_at?: boolean;
    /**
     * The workspace's description.
     */
    description?: boolean;
    /**
     * The workspace's unique identifier.
     */
    id?: boolean;
    /**
     * The workspace's kind (open / closed).
     */
    kind?: boolean;
    /**
     * The workspace's name.
     */
    name?: boolean;
    /**
     * The workspace's user owners.
     */
    owners_subscribers?: {
        args?: {
            /**
             * Number of items to get, the default is 25.
             */
            limit?: number;
            /**
             * Page number to get, starting at 1.
             */
            page?: number;
        };
        fields: UserFields;
    };
    /**
     * The workspace's settings.
     */
    settings?: {
        fields: WorkspaceSettingsFields;
    };
    /**
     * The workspace's state (all / active / archived / deleted).
     */
    state?: boolean;
    /**
     * The workspace's team owners.
     */
    team_owners_subscribers?: {
        args?: {
            /**
             * Number of items to get, the default is 25.
             */
            limit?: number;
            /**
             * Page number to get, starting at 1.
             */
            page?: number;
        };
        fields: TeamFields;
    };
    /**
     * The teams subscribed to the workspace.
     */
    teams_subscribers?: {
        args?: {
            /**
             * Number of items to get, the default is 25.
             */
            limit?: number;
            /**
             * Page number to get, starting at 1.
             */
            page?: number;
        };
        fields: TeamFields;
    };
    /**
     * The users subscribed to the workspace
     */
    users_subscribers?: {
        args?: {
            /**
             * Number of items to get, the default is 25.
             */
            limit?: number;
            /**
             * Page number to get, starting at 1.
             */
            page?: number;
        };
        fields: UserFields;
    };
}
export interface WorkspaceReturnType {
    /**
     * The account product that contains workspace.
     */
    account_product: AccountProductReturnType | null;
    /**
     * The workspace's creation date.
     */
    created_at: string | null;
    /**
     * The workspace's description.
     */
    description: string | null;
    /**
     * The workspace's unique identifier.
     */
    id: number | null;
    /**
     * The workspace's kind (open / closed).
     */
    kind: WorkspaceKind | null;
    /**
     * The workspace's name.
     */
    name: string;
    /**
     * The workspace's user owners.
     */
    owners_subscribers: UserReturnType[] | null;
    /**
     * The workspace's settings.
     */
    settings: WorkspaceSettingsReturnType | null;
    /**
     * The workspace's state (all / active / archived / deleted).
     */
    state: State | null;
    /**
     * The workspace's team owners.
     */
    team_owners_subscribers: TeamReturnType[];
    /**
     * The teams subscribed to the workspace.
     */
    teams_subscribers: TeamReturnType[] | null;
    /**
     * The users subscribed to the workspace
     */
    users_subscribers: UserReturnType[] | null;
}
export declare type WorkspaceSubscriberKind = 'owner' | 'subscriber';
export declare type WorkspaceKind = 'open' | 'closed';
export declare type State = 'all' | 'active' | 'archived' | 'deleted';
export declare type WorkspacesOrderBy = 'created_at';
//# sourceMappingURL=workspace.d.ts.map