/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { BaseApiCore, Headers, Response, ErrorStrategyOptionType, PlatformImplementation } from '@managed-api/commons-core';
import { CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyOption } from './errorStrategy';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { ArchiveBoardFullResponseOK, ArchiveBoardRequest, ArchiveBoardResponseOK, CreateBoardFullResponseOK, CreateBoardRequest, CreateBoardResponseOK, DeleteBoardFullResponseOK, DeleteBoardRequest, DeleteBoardResponseOK, DeleteSubscribersBoardFullResponseOK, DeleteSubscribersBoardRequest, DeleteSubscribersBoardResponseOK, DuplicateBoardFullResponseOK, DuplicateBoardRequest, DuplicateBoardResponseOK, GetBoardViewsFullResponseOK, GetBoardViewsRequest, GetBoardViewsResponseOK, GetBoardsFullResponseOK, GetBoardsRequest, GetBoardsResponseOK, UpdateBoardFullResponseOK, UpdateBoardRequest, UpdateBoardResponseOK, GetBoardGroupsFullResponseOK, GetBoardGroupsRequest, GetBoardGroupsResponseOK, CreateBoardGroupFullResponseOK, CreateBoardGroupRequest, CreateBoardGroupResponseOK, DeleteBoardGroupResponseOK, DeleteBoardGroupFullResponseOK, DeleteBoardGroupRequest, ArchiveBoardGroupFullResponseOK, ArchiveBoardGroupRequest, ArchiveBoardGroupResponseOK, DuplicateBoardGroupFullResponseOK, DuplicateBoardGroupRequest, DuplicateBoardGroupResponseOK, UpdateBoardGroupFullResponseOK, UpdateBoardGroupRequest, UpdateBoardGroupResponseOK } from './types/board';
import { ArchiveItemFullResponseOK, ArchiveItemRequest, ArchiveItemResponseOK, ClearItemUpdatesFullResponseOK, ClearItemUpdatesRequest, ClearItemUpdatesResponseOK, CreateItemFullResponseOK, CreateItemRequest, CreateItemResponseOK, DeleteItemFullResponseOK, DeleteItemRequest, DeleteItemResponseOK, DuplicateItemFullResponseOK, DuplicateItemRequest, DuplicateItemResponseOK, GetItemsFullResponseOK, GetItemsRequest, GetItemsResponseOK, MoveItemToBoardFullResponseOK, MoveItemToBoardRequest, MoveItemToBoardResponseOK, MoveItemToGroupFullResponseOK, MoveItemToGroupRequest, MoveItemToGroupResponseOK } from './types/item';
import { GetUserDetailsFullResponseOK, GetUserDetailsRequest, GetUserDetailsResponseOK } from './types/me';
import { CreateSubitemFullResponseOK, CreateSubitemRequest, CreateSubitemResponseOK, GetSubitemsFullResponseOK, GetSubitemsRequest, GetSubitemsResponseOK } from './types/subitem';
import { AddUsersToBoardFullResponseOK, AddUsersToBoardRequest, AddUsersToBoardResponseOK, AddUsersToWorkspaceFullResponseOK, AddUsersToWorkspaceRequest, AddUsersToWorkspaceResponseOK, DeleteUsersFromWorkspaceFullResponseOK, DeleteUsersFromWorkspaceRequest, DeleteUsersFromWorkspaceResponseOK, GetUsersFullResponseOK, GetUsersRequest, GetUsersResponseOK } from './types/user';
import { AddFileToColumnFullResponseOK, AddFileToColumnRequest, AddFileToColumnResponseOK, AddFileToUpdateFullResponseOK, AddFileToUpdateRequest, AddFileToUpdateResponseOK, GetAssetsFullResponseOK, GetAssetsRequest, GetAssetsResponseOK } from './types/assets';
import { ChangeColumnMetadataFullResponseOK, ChangeColumnMetadataRequest, ChangeColumnMetadataResponseOK, ChangeColumnTitleFullResponseOK, ChangeColumnTitleRequest, ChangeColumnTitleResponseOK, ChangeColumnValueFullResponseOK, ChangeColumnValueRequest, ChangeColumnValueResponseOK, ChangeMultipleColumnValuesFullResponseOK, ChangeMultipleColumnValuesRequest, ChangeMultipleColumnValuesResponseOK, ChangeSimpleColumnValueFullResponseOK, ChangeSimpleColumnValueRequest, ChangeSimpleColumnValueResponseOK, CreateColumnFullResponseOK, CreateColumnRequest, CreateColumnResponseOK, DeleteColumnFullResponseOK, DeleteColumnRequest, DeleteColumnResponseOK } from './types/column';
import { CreateNotificationFullResponseOK, CreateNotificationRequest, CreateNotificationResponseOK } from './types/notification';
import { CreateWorkspaceFullResponseOK, CreateWorkspaceRequest, CreateWorkspaceResponseOK, DeleteWorkspaceFullResponseOK, DeleteWorkspaceRequest, DeleteWorkspaceResponseOK, GetWorkspacesFullResponseOK, GetWorkspacesRequest, GetWorkspacesResponseOK, UpdateWorkspaceFullResponseOK, UpdateWorkspaceRequest, UpdateWorkspaceResponseOK } from './types/workspace';
import { AddTeamsToBoardFullResponseOK, AddTeamsToBoardRequest, AddTeamsToBoardResponseOK, AddTeamsToWorkspaceFullResponseOK, AddTeamsToWorkspaceRequest, AddTeamsToWorkspaceResponseOK, AddUsersToTeamFullResponseOK, AddUsersToTeamRequest, AddUsersToTeamResponseOK, DeleteTeamsFromBoardFullResponseOK, DeleteTeamsFromBoardRequest, DeleteTeamsFromBoardResponseOK, DeleteTeamsFromWorkspaceFullResponseOK, DeleteTeamsFromWorkspaceRequest, DeleteTeamsFromWorkspaceResponseOK, GetTeamsFullResponseOK, GetTeamsRequest, GetTeamsResponseOK, RemoveUsersFromTeamFullResponseOK, RemoveUsersFromTeamRequest, RemoveUsersFromTeamResponseOK } from './types/team';
import { CreateUpdateFullResponseOK, CreateUpdateRequest, CreateUpdateResponseOK, DeleteUpdateFullResponseOK, DeleteUpdateRequest, DeleteUpdateResponseOK, GetUpdatesFullResponseOK, GetUpdatesRequest, GetUpdatesResponseOK, LikeUpdateFullResponseOK, LikeUpdateRequest, LikeUpdateResponseOK } from './types/update';
import { GetItemsPageByColumnValuesFullResponseOK, GetItemsPageByColumnValuesRequest, GetItemsPageByColumnValuesResponseOK, GetItemsPageFullResponseOK, GetItemsPageRequest, GetItemsPageResponseOK, GetNextItemsPageFullResponseOK, GetNextItemsPageRequest, GetNextItemsPageResponseOK } from './types/itemsPage';
import { CreateDocFullResponseOK, CreateDocRequest, CreateDocResponseOK, GetDocsFullResponseOK, GetDocsRequest, GetDocsResponseOK } from './types/doc';
import { CreateDocBlockFullResponseOK, CreateDocBlockRequest, CreateDocBlockResponseOK, DeleteDocBlockFullResponseOK, DeleteDocBlockRequest, DeleteDocBlockResponseOK, GetDocBlocksFullResponseOK, GetDocBlocksRequest, GetDocBlocksResponseOK, UpdateDocBlockFullResponseOK, UpdateDocBlockRequest, UpdateDocBlockResponseOK } from './types/docBlock';
import { CreateOrGetTagRequest, CreateOrGetTagResponseOK, GetBoardTagsFullResponseOK, GetBoardTagsRequest, GetBoardTagsResponseOK, GetTagsFullResponseOK, GetTagsRequest, GetTagsResponseOK } from './types/tag';
import { GetVersionFullResponseOK, GetVersionRequest, GetVersionResponseOK, GetVersionsFullResponseOK, GetVersionsRequest, GetVersionsResponseOK } from './types/version';
import { CreateWebhookRequest, CreateWebhookResponseOK, CreateWebhooksFullResponseOK, DeleteWebhookRequest, DeleteWebhookResponseOK, DeleteWebhooksFullResponseOK, GetWebhooksFullResponseOK, GetWebhooksRequest, GetWebhooksResponseOK } from './types/webhook';
import { GetFoldersFullResponseOK, GetFoldersRequest, GetFoldersResponseOK, CreateFolderFullResponseOK, CreateFolderRequest, CreateFolderResponseOK, UpdateFolderFullResponseOK, UpdateFolderRequest, UpdateFolderResponseOK, DeleteFolderFullResponseOK, DeleteFolderRequest, DeleteFolderResponseOK } from './types/folder';
export interface MondayApiCoreOptions extends ErrorStrategyOption {
}
export declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class MondayApiCore extends BaseApiCore {
    private options?;
    Board: BoardGroup;
    Item: ItemGroup;
    Me: MeGroup;
    User: UserGroup;
    File: FileGroup;
    Column: ColumnGroup;
    Notification: NotificationGroup;
    Workspace: WorkspaceGroup;
    Folder: FolderGroup;
    Update: UpdateGroup;
    Team: TeamGroup;
    ItemsPage: ItemsPageGroup;
    Doc: DocGroup;
    Tag: TagGroup;
    Version: VersionGroup;
    Webhook: WebhookGroup;
    All: AllGroup;
    constructor(options?: MondayApiCoreOptions | undefined);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Board;
    private Item;
    private Me;
    private User;
    private File;
    private Column;
    private Notification;
    private Workspace;
    private Folder;
    private Update;
    private Team;
    private ItemsPage;
    private Doc;
    private Tag;
    private Version;
    private Webhook;
    constructor(Board: BoardGroup, Item: ItemGroup, Me: MeGroup, User: UserGroup, File: FileGroup, Column: ColumnGroup, Notification: NotificationGroup, Workspace: WorkspaceGroup, Folder: FolderGroup, Update: UpdateGroup, Team: TeamGroup, ItemsPage: ItemsPageGroup, Doc: DocGroup, Tag: TagGroup, Version: VersionGroup, Webhook: WebhookGroup);
    /**
     * The create_column mutation allows you to create a new column on a board within the account via the API.
     * The create_column mutation also allows you to create a new status or dropdown column with custom labels via the API.
     * Alternative usage: Column.createColumn
     * Documentation: https://developer.monday.com/api-reference/docs/columns#create-a-column
     * @param options Request options.
     */
    createColumn<T = CreateColumnFullResponseOK, S extends CreateColumnRequest = CreateColumnRequest>(options: S): Promise<CreateColumnResponseOK<S> | T>;
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item.
     * Alternative usage: Column.changeColumnValue
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-value
     * @param options Request options.
     */
    changeColumnValue<T = ChangeColumnValueFullResponseOK, S extends ChangeColumnValueRequest = ChangeColumnValueRequest>(options: S): Promise<ChangeColumnValueResponseOK<S> | T>;
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item with a string value.
     * Alternative usage: Column.changeSimpleColumnValue
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-simple-column-value
     * @param options Request options.
     */
    changeSimpleColumnValue<T = ChangeSimpleColumnValueFullResponseOK, S extends ChangeSimpleColumnValueRequest = ChangeSimpleColumnValueRequest>(options: S): Promise<ChangeSimpleColumnValueResponseOK<S> | T>;
    /**
     * The change_multiple_column_values mutation allows you to change multiple column values of a specific item.
     * Alternative usage: Column.changeMultipleColumnValues
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-multiple-column-values
     * @param options Request options.
     */
    changeMultipleColumnValues<T = ChangeMultipleColumnValuesFullResponseOK, S extends ChangeMultipleColumnValuesRequest = ChangeMultipleColumnValuesRequest>(options: S): Promise<ChangeMultipleColumnValuesResponseOK<S> | T>;
    /**
     * The change_column_title mutation allows you to change the title of an existing column via the API.
     * Alternative usage: Column.changeColumnTitle
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-title
     * @param options Request options.
     */
    changeColumnTitle<T = ChangeColumnTitleFullResponseOK, S extends ChangeColumnTitleRequest = ChangeColumnTitleRequest>(options: S): Promise<ChangeColumnTitleResponseOK<S> | T>;
    /**
     * The change_column_metadata mutation allows you to update the metadata of an existing column.
     * Currently, we support updating both the title and description.
     * Alternative usage: Column.changeColumnMetadata
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-column-metadata
     * @param options Request options.
     */
    changeColumnMetadata<T = ChangeColumnMetadataFullResponseOK, S extends ChangeColumnMetadataRequest = ChangeColumnMetadataRequest>(options: S): Promise<ChangeColumnMetadataResponseOK<S> | T>;
    /**
     * The delete_column mutation allows you to delete a single column from a board via the API.
     * Alternative usage: Column.deleteColumn
     * Documentation: https://developer.monday.com/api-reference/docs/columns#delete-a-column
     * @param options Request options.
     */
    deleteColumn<T = DeleteColumnFullResponseOK, S extends DeleteColumnRequest = DeleteColumnRequest>(options: S): Promise<DeleteColumnResponseOK<S> | T>;
    /**
     * Querying boards will return metadata about one or a collection of boards. This method accepts various arguments and returns an array.
     * Alternative usage: Board.getBoards
     * Documentation: https://developer.monday.com/api-reference/docs/boards#queries
     * @param options Request options.
     */
    getBoards<T = GetBoardsFullResponseOK, S extends GetBoardsRequest = GetBoardsRequest>(options: S): Promise<GetBoardsResponseOK<S> | T>;
    /**
     * The create_board mutation allows you to create a new board via the API.
     * You can also specify what fields to query back from the new board when you run the mutation.
     * Please note that the user that creates the board via the API will automatically be added as the board's owner when creating a private or shareable board or if the board_owners_ids argument is missing.
     * Alternative usage: Board.createBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#create-a-board
     * @param options Request options.
     */
    createBoard<T = CreateBoardFullResponseOK, S extends CreateBoardRequest = CreateBoardRequest>(options: S): Promise<CreateBoardResponseOK<S> | T>;
    /**
     * The duplicate_board mutation allows you to duplicate a board with all of its items and groups to a specific workspace or folder of your choice via the API.
     * Alternative usage: Board.duplicateBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#duplicate-a-board
     * @param options Request options.
     */
    duplicateBoard<T = DuplicateBoardFullResponseOK, S extends DuplicateBoardRequest = DuplicateBoardRequest>(options: S): Promise<DuplicateBoardResponseOK<S> | T>;
    /**
     * The update_board mutation allows you to update a board via the API.
     * Alternative usage: Board.updateBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#update-a-board
     * @param options Request options.
     */
    updateBoard<T = UpdateBoardFullResponseOK>(options: UpdateBoardRequest): Promise<UpdateBoardResponseOK | T>;
    /**
     * The archive_board mutation allows you to archive a board via the API. You can also specify what fields to query back from the archived board when you run the mutation.
     * Alternative usage: Board.archiveBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#archive-a-board
     * @param options Request options.
     */
    archiveBoard<T = ArchiveBoardFullResponseOK, S extends ArchiveBoardRequest = ArchiveBoardRequest>(options: S): Promise<ArchiveBoardResponseOK<S> | T>;
    /**
     * The delete_board mutation allows you to delete a board via the API. You can also specify what fields to query back from the deleted board when you run the mutation.
     * Alternative usage: Board.deleteBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-a-board
     * @param options Request options.
     */
    deleteBoard<T = DeleteBoardFullResponseOK, S extends DeleteBoardRequest = DeleteBoardRequest>(options: S): Promise<DeleteBoardResponseOK<S> | T>;
    /**
     * The delete_subscribers_from_board mutation allows you to delete subscribers from a board via the API. You can also specify what fields to query back from the subscribers you delete from the board when you run the mutation.
     * Alternative usage: Board.deleteSubscribersFromBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-subscribers-from-a-board
     * @param options Request options.
     */
    deleteSubscribersFromBoard<T = DeleteSubscribersBoardFullResponseOK, S extends DeleteSubscribersBoardRequest = DeleteSubscribersBoardRequest>(options: S): Promise<DeleteSubscribersBoardResponseOK<S> | T>;
    /**
     * Querying items_page will return items filtered by the specified criteria. This method accepts various arguments and returns an object.
     * Alternative usage: Board.ItemsPage.getItemsPage
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#queries
     * @param options Request options.
     */
    getItemsPage<T = GetItemsPageFullResponseOK, S extends GetItemsPageRequest = GetItemsPageRequest>(options: S): Promise<GetItemsPageResponseOK<S> | T>;
    /**
     * Querying next_items_page will return the next set of items that correspond with the provided cursor. This method accepts various arguments and returns an object.
     * Alternative usage: ItemsPage.getNextItemsPage
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#cursor-based-pagination-using-next_items_page
     * @param options Request options.
     */
    getNextItemsPage<T = GetNextItemsPageFullResponseOK, S extends GetNextItemsPageRequest = GetNextItemsPageRequest>(options: S): Promise<GetNextItemsPageResponseOK<S> | T>;
    /**
     * Querying items_page_by_column_values will search for items based on predefined column values and return metadata about these specific items. This method accepts various arguments and returns an array.
     * Alternative usage: ItemsPage.getItemsPageByColumnValues
     * Documentation: https://developer.monday.com/api-reference/docs/items-page-by-column-values
     * @param options Request options.
     */
    getItemsPageByColumnValues<T = GetItemsPageByColumnValuesFullResponseOK, S extends GetItemsPageByColumnValuesRequest = GetItemsPageByColumnValuesRequest>(options: S): Promise<GetItemsPageByColumnValuesResponseOK<S> | T>;
    /**
     * Querying views will return a collection of board views from a specific board. This method accepts various arguments and returns an array.
     * You can only query views by nesting it within a boards query, so it can't be used at the root.
     * Alternative usage: Board.View.getViews
     * Documentation: https://developer.monday.com/api-reference/docs/board-view-queries#queries
     * @param options Request options.
     */
    getBoardViews<T = GetBoardViewsFullResponseOK, S extends GetBoardViewsRequest = GetBoardViewsRequest>(options: S): Promise<GetBoardViewsResponseOK<S> | T>;
    /**
     * Querying groups will return metadata about one or a collection of groups on a specific board. This method accepts one argument and returns an array.	 *
     * You can only query groups by nesting it within another query, so it can't be used at the root.
     * Alternative usage: Board.Group.getGroups
     * Documentation: https://developer.monday.com/api-reference/docs/groups#queries
     * @param options Request options.
     */
    getBoardGroups<T = GetBoardGroupsFullResponseOK, S extends GetBoardGroupsRequest = GetBoardGroupsRequest>(options: S): Promise<GetBoardGroupsResponseOK<S> | T>;
    /**
     * The create_group mutation allows you to create a new empty group via the API. You can also specify what fields to query back from the new group when you run the mutation.
     * Alternative usage: Board.Group.createGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#create-a-group
     * @param options
     */
    createGroup<T = CreateBoardGroupFullResponseOK, S extends CreateBoardGroupRequest = CreateBoardGroupRequest>(options: S): Promise<CreateBoardGroupResponseOK<S> | T>;
    /**
     * The update_group mutation allows you to update an existing group via the API. You can also specify what fields to query back from the updated group when you run the mutation.
     * Alternative usage: Board.Group.updateGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#update-a-group
     * @param options
     */
    updateGroup<T = UpdateBoardGroupFullResponseOK, S extends UpdateBoardGroupRequest = UpdateBoardGroupRequest>(options: S): Promise<UpdateBoardGroupResponseOK<S> | T>;
    /**
     * The duplicate_group mutation allows you to duplicate a group with all of its items via the API. You can also specify what fields to query back from the duplicated group when you run the mutation.
     * Alternative usage: Board.Group.duplicateGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#duplicate-group
     * (!) Mutation-specific rate limit:
     * The duplicate_group mutation has an additional rate limit of 40 mutations per minute. If you exceed this limit, you will receive a response with a 429 status code, and the following error message: "Call limit exceeded for DuplicateGroup".
     * @param options
     */
    duplicateGroup<T = DuplicateBoardGroupFullResponseOK, S extends DuplicateBoardGroupRequest = DuplicateBoardGroupRequest>(options: S): Promise<DuplicateBoardGroupResponseOK<S> | T>;
    /**
     * The archive_group mutation allows you to archive a group with all of its items via the API. You can also specify what fields to query back from the archived group when you run the mutation.
     * Alternative usage: Board.Group.archiveGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#archive-a-group
     * @param options
     */
    archiveGroup<T = ArchiveBoardGroupFullResponseOK, S extends ArchiveBoardGroupRequest = ArchiveBoardGroupRequest>(options: S): Promise<ArchiveBoardGroupResponseOK<S> | T>;
    /**
     * The delete_group mutation allows you to delete a group with all of its items via the API. You can also specify what fields to query back from the deleted group when you run the mutation.
     * Alternative usage: Board.Group.deleteGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#delete-a-group
     * @param options
     */
    deleteGroup<T = DeleteBoardGroupFullResponseOK, S extends DeleteBoardGroupRequest = DeleteBoardGroupRequest>(options: S): Promise<DeleteBoardGroupResponseOK<S> | T>;
    /**
     * Querying items will return metadata about one or a collection of items. This method accepts various arguments and returns an array.
     * Alternative usage: Item.getItems
     * Documentation: https://developer.monday.com/api-reference/docs/items#queries
     * @param options Request options.
     */
    getItems<T = GetItemsFullResponseOK, S extends GetItemsRequest = GetItemsRequest>(options: S): Promise<GetItemsResponseOK<S> | T>;
    /**
     * The create_item mutation allows you to create a new item via the API. You can also specify what fields to query back from the new item when you run the mutation.
     * Alternative usage: Item.createItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#create-an-item
     * @param options Request options.
     */
    createItem<T = CreateItemFullResponseOK, S extends CreateItemRequest = CreateItemRequest>(options: S): Promise<CreateItemResponseOK<S> | T>;
    /**
     * The duplicate_item mutation allows you to duplicate a single item via the API. You can also specify what fields to query back from the duplicated item when you run the mutation.
     * Alternative usage: Item.duplicateItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#duplicate-an-item
     * @param options Request options.
     */
    duplicateItem<T = DuplicateItemFullResponseOK, S extends DuplicateItemRequest = DuplicateItemRequest>(options: S): Promise<DuplicateItemResponseOK<S> | T>;
    /**
     * The move_item_to_group mutation allows you to move an item between groups on the same board via the API. You can also specify what fields to query back from the item when you run the mutation.
     * Alternative usage: Item.moveItemToGroup
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-group
     * @param options Request options.
     */
    moveItemToGroup<T = MoveItemToGroupFullResponseOK, S extends MoveItemToGroupRequest = MoveItemToGroupRequest>(options: S): Promise<MoveItemToGroupResponseOK<S> | T>;
    /**
     * The move_item_to_board mutation allows you to move an item to another board via the API. You can also specify what fields to query back from the item moved when you run the mutation.
     * Alternative usage: Item.moveItemToBoard
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-board
     * @param options Request options.
     */
    moveItemToBoard<T = MoveItemToBoardFullResponseOK, S extends MoveItemToBoardRequest = MoveItemToBoardRequest>(options: S): Promise<MoveItemToBoardResponseOK<S> | T>;
    /**
     * The archive_item mutation allows you to archive a single item via the API. You can also specify what fields to query back from the archived item when you run the mutation.
     * Alternative usage: Item.archiveItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#archive-an-item
     * @param options Request options.
     */
    archiveItem<T = ArchiveItemFullResponseOK, S extends ArchiveItemRequest = ArchiveItemRequest>(options: S): Promise<ArchiveItemResponseOK<S> | T>;
    /**
     * The delete_item mutation allows you to delete a single item via the API. You can also specify what fields to query back from the deleted item when you run the mutation.
     * Alternative usage: Item.deleteItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#delete-an-item
     * @param options Request options.
     */
    deleteItem<T = DeleteItemFullResponseOK, S extends DeleteItemRequest = DeleteItemRequest>(options: S): Promise<DeleteItemResponseOK<S> | T>;
    /**
     * The clear_item_updates mutation allows you to clear all updates on a specific item, including replies and likes. You can also specify what fields to query back from the item when you run the mutation.
     * Alternative usage: Item.clearUpdates
     * Documentation: https://developer.monday.com/api-reference/docs/items#clear-an-items-updates
     * @param options Request options.
     */
    clearItemUpdates<T = ClearItemUpdatesFullResponseOK, S extends ClearItemUpdatesRequest = ClearItemUpdatesRequest>(options: S): Promise<ClearItemUpdatesResponseOK<S> | T>;
    /**
     * Querying subitems will return metadata about one or a collection of subitems. This method does not accept any arguments and returns an array.
     * You can only query subitems by nesting it within another query, so it can't be used at the root.
     * Alternative usage: Item.Subitem.getSubitems
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#queries
     * @param options Request options.
     */
    getSubitems<T = GetSubitemsFullResponseOK, S extends GetSubitemsRequest = GetSubitemsRequest>(options: S): Promise<GetSubitemsResponseOK<S> | T>;
    /**
     * The create_subitem mutation allows you to create a new subitem via the API. You can also specify what fields to query back from the new subitem when you run the mutation.
     * Alternative usage: Item.Subitem.createSubitem
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#create-a-subitem
     * @param options Request options.
     */
    createSubitem<T = CreateSubitemFullResponseOK, S extends CreateSubitemRequest = CreateSubitemRequest>(options: S): Promise<CreateSubitemResponseOK<S> | T>;
    /**
     * Querying me will return metadata about the user whose API key is being used. This method does not accept any arguments and returns an object.
     * You can only query me directly at the root, so it can't be nested within another query.
     * Alternative usage: Me.getUserDetails
     * Documentation: https://developer.monday.com/api-reference/docs/me#queries
     * @param options Request options.
     */
    getUserDetails<T = GetUserDetailsFullResponseOK, S extends GetUserDetailsRequest = GetUserDetailsRequest>(options: S): Promise<GetUserDetailsResponseOK<S> | T>;
    /**
     * Querying users will return metadata about one or multiple users. This method accepts various arguments and returns an array.
     * Alternative usage: User.getUsers
     * Documentation: https://developer.monday.com/api-reference/docs/users#queries
     * @param options Request options.
     */
    getUsers<T = GetUsersFullResponseOK, S extends GetUsersRequest = GetUsersRequest>(options: S): Promise<GetUsersResponseOK<S> | T>;
    /**
     * The add_users_to_board mutation allows you to add users to a board via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Alternative usage: User.addUsersToBoard
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-board
     * @param options Request options.
     */
    addUsersToBoard<T = AddUsersToBoardFullResponseOK, S extends AddUsersToBoardRequest = AddUsersToBoardRequest>(options: S): Promise<AddUsersToBoardResponseOK<S> | T>;
    /**
     * The add_users_to_workspace mutation allows you to add users to a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Alternative usage: User.addUsersToWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-workspace
     * @param options Request options.
     */
    addUsersToWorkspace<T = AddUsersToWorkspaceFullResponseOK, S extends AddUsersToWorkspaceRequest = AddUsersToWorkspaceRequest>(options: S): Promise<AddUsersToWorkspaceResponseOK<S> | T>;
    /**
     * The delete_users_from_workspace mutation allows you to delete users from a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Alternative usage: User.deleteUsersFromWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/users#delete-users-from-a-workspace
     * @param options Request options.
     */
    deleteUsersFromWorkspace<T = DeleteUsersFromWorkspaceFullResponseOK, S extends DeleteUsersFromWorkspaceRequest = DeleteUsersFromWorkspaceRequest>(options: S): Promise<DeleteUsersFromWorkspaceResponseOK<S> | T>;
    /**
     * Querying assets will return one or a collection of assets. This method accepts various arguments and returns an array.
     * Alternative usage: File.getAssets
     * Documentation: https://developer.monday.com/api-reference/docs/files#queries
     * @param options Request options.
     */
    getAssets<T = GetAssetsFullResponseOK, S extends GetAssetsRequest = GetAssetsRequest>(options: S): Promise<GetAssetsResponseOK<S> | T>;
    /**
     * The add_file_to_update mutation allows you to add a file to an update via the API. You can also specify what fields to query back when you run the mutation. Please note that the file will be added to the bottom of the update.
     * Alternative usage: File.addFileToUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-a-file-to-an-update
     * @param options Request options.
     */
    addFileToUpdate<T = AddFileToUpdateFullResponseOK, S extends AddFileToUpdateRequest = AddFileToUpdateRequest>(options: S): Promise<AddFileToUpdateResponseOK<S> | T>;
    /**
     * The add_file_to_column mutation will add a file to the file column of a specific item. You can also specify what fields to query back when you run the mutation.
     * Alternative usage: File.addFileToColumn
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-file-to-the-file-column
     * @param options Request options.
     */
    addFileToColumn<T = AddFileToColumnFullResponseOK, S extends AddFileToColumnRequest = AddFileToColumnRequest>(options: S): Promise<AddFileToColumnResponseOK<S> | T>;
    /**
     * The create_notification mutation allows you to send a notification to the bell icon via the API. Doing so may also send an email if the recipient's email preferences are set up accordingly.
     * Please note that this mutation only sends the notification; you can't query back the notification ID when running the mutation, as notifications are asynchronous.
     * Alternative usage: Notification.createNotification
     * Documentation: https://developer.monday.com/api-reference/docs/notification#create-a-notification
     * @param options Request options.
     */
    createNotification<T = CreateNotificationFullResponseOK, S extends CreateNotificationRequest = CreateNotificationRequest>(options: S): Promise<CreateNotificationResponseOK<S> | T>;
    /**
     * Querying workspaces will return metadata about one or a collection of workspaces. This method accepts various arguments and returns an array.
     * Alternative usage: Workspace.getWorkspaces
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#queries
     * @param options Request options.
     */
    getWorkspaces<T = GetWorkspacesFullResponseOK, S extends GetWorkspacesRequest = GetWorkspacesRequest>(options: S): Promise<GetWorkspacesResponseOK<S> | T>;
    /**
     * The create_workspace mutation allows you to create a new workspace via the API.
     * You can also specify what fields to query back from the new workspace when you run the mutation.
     * Alternative usage: Workspace.createWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#create-a-workspace
     * @param options Request options.
     */
    createWorkspace<T = CreateWorkspaceFullResponseOK, S extends CreateWorkspaceRequest = CreateWorkspaceRequest>(options: S): Promise<CreateWorkspaceResponseOK<S> | T>;
    /**
     * The update_workspace mutation allows you to update a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Alternative usage: Workspace.updateWorkspace
     * Documentation: https://developer.monday.com/api-reference/reference/workspaces#update-a-workspace
     * @param options Request options.
     */
    updateWorkspace<T = UpdateWorkspaceFullResponseOK, S extends UpdateWorkspaceRequest = UpdateWorkspaceRequest>(options: S): Promise<UpdateWorkspaceResponseOK<S> | T>;
    /**
     * The delete_workspace mutation allows you to delete a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Alternative usage: Workspace.deleteWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#delete-a-workspace
     * @param options Request options.
     */
    deleteWorkspace<T = DeleteWorkspaceFullResponseOK, S extends DeleteWorkspaceRequest = DeleteWorkspaceRequest>(options: S): Promise<DeleteWorkspaceResponseOK<S> | T>;
    /**
     * Querying updates will return metadata about one or a collection of updates.
     * This method accepts various arguments and returns an array.
     * Alternative usage: Update.getUpdates
     * Documentation: https://developer.monday.com/api-reference/docs/updates#queries
     * @param options Request options.
     */
    getUpdates<T = GetUpdatesFullResponseOK, S extends GetUpdatesRequest = GetUpdatesRequest>(options: S): Promise<GetUpdatesResponseOK<S> | T>;
    /**
     * The create_update mutation allows you to add an update to an item via the API.
     * You can also specify what fields to query back from the new update when you run the mutation.
     * Alternative usage: Update.createUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/updates#create-an-update
     * @param options Request options.
     */
    createUpdate<T = CreateUpdateFullResponseOK, S extends CreateUpdateRequest = CreateUpdateRequest>(options: S): Promise<CreateUpdateResponseOK<S> | T>;
    /**
     * The delete_update mutation allows you to delete an item's update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Alternative usage: Update.deleteUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/updates#delete-an-update
     * @param options Request options.
     */
    deleteUpdate<T = DeleteUpdateFullResponseOK, S extends DeleteUpdateRequest = DeleteUpdateRequest>(options: S): Promise<DeleteUpdateResponseOK<S> | T>;
    /**
     * The like_update mutation allows you to like an update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Alternative usage: Update.likeUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/updates#like-an-update
     * @param options Request options.
     */
    likeUpdate<T = LikeUpdateFullResponseOK, S extends LikeUpdateRequest = LikeUpdateRequest>(options: S): Promise<LikeUpdateResponseOK<S> | T>;
    /**
     * Querying teams will return metadata about one or several teams. This method accepts one argument and returns an array.
     * You can query teams directly at the root, or you can nest it within a users query to return the teams a specific user is part of. Please note that nesting your query will increase its complexity.
     * Alternative: Team.getTeam
     * Documentation: https://developer.monday.com/api-reference/docs/teams#queries
     * @param options
     */
    getTeams<T = GetTeamsFullResponseOK, S extends GetTeamsRequest = GetTeamsRequest>(options: S): Promise<GetTeamsResponseOK<S> | T>;
    /**
     * The add_teams_to_board mutation allows you to add teams to a board via the API. You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.addTeamsToBoard
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-board
     * @param options
     */
    addTeamsToBoard<T = AddTeamsToBoardFullResponseOK, S extends AddTeamsToBoardRequest = AddTeamsToBoardRequest>(options: S): Promise<AddTeamsToBoardResponseOK<S> | T>;
    /**
     * The add_teams_to_workspace mutation allows you to add teams to a workspace via the API. You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.addTeamsToWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-workspace
     * @param options
     */
    addTeamsToWorkspace<T = AddTeamsToWorkspaceFullResponseOK, S extends AddTeamsToWorkspaceRequest = AddTeamsToWorkspaceRequest>(options: S): Promise<AddTeamsToWorkspaceResponseOK<S> | T>;
    /**
     * The delete_teams_from_workspace mutation allows you to delete teams from a workspace via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.deleteTeamsFromWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-workspace
     * @param options
     */
    deleteTeamsFromWorkspace<T = DeleteTeamsFromWorkspaceFullResponseOK, S extends DeleteTeamsFromWorkspaceRequest = DeleteTeamsFromWorkspaceRequest>(options: S): Promise<DeleteTeamsFromWorkspaceResponseOK<S> | T>;
    /**
     * The delete_teams_from_board mutation allows you to delete teams from a board via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.deleteTeamsFromBoard
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-board
     * @param options
     */
    deleteTeamsFromBoard<T = DeleteTeamsFromBoardFullResponseOK, S extends DeleteTeamsFromBoardRequest = DeleteTeamsFromBoardRequest>(options: S): Promise<DeleteTeamsFromBoardResponseOK<S> | T>;
    /**
     * The add_users_to_team mutation allows you to add users to a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Alternative: Team.addUsersToTeam
     * Documentation: https://developer.monday.com/api-reference/reference/users#add-users-to-a-team
     * @param options
     */
    addUsersToTeam<T = AddUsersToTeamFullResponseOK, S extends AddUsersToTeamRequest = AddUsersToTeamRequest>(options: S): Promise<AddUsersToTeamResponseOK<S> | T>;
    /**
     * The remove_users_from_team mutation allows you to remove users from a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Alternative: Team.removeUsersFromTeam
     * Documentation: https://developer.monday.com/api-reference/reference/users#remove-users-from-a-team
     * @param options
     */
    removeUsersFromTeam<T = RemoveUsersFromTeamFullResponseOK, S extends RemoveUsersFromTeamRequest = RemoveUsersFromTeamRequest>(options: S): Promise<RemoveUsersFromTeamResponseOK<S> | T>;
    /**
     * Querying docs will return metadata about a collection of docs. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#queries
     * Alternative: Doc.getDocs
     * @param options Request options.
     */
    getDocs<T = GetDocsFullResponseOK, S extends GetDocsRequest = GetDocsRequest>(options: S): Promise<GetDocsResponseOK<S> | T>;
    /**
     * The create_doc mutation allows you to create a new doc in a document column or workspace via the API. You can also specify what fields to query back from the new doc when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#create-a-doc
     * Alternative: Doc.createDoc
     * @param options Request options.
     */
    createDoc<T = CreateDocFullResponseOK, S extends CreateDocRequest = CreateDocRequest>(options: S): Promise<CreateDocResponseOK<S> | T>;
    /**
     * Querying blocks will return metadata about one or a collection of blocks. The method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#queries
     * Alternative: Doc.DocBlock.getDocBlocks
     * @param options Request options.
     */
    getDocBlocks<T = GetDocBlocksFullResponseOK, S extends GetDocBlocksRequest = GetDocBlocksRequest>(options: S): Promise<GetDocBlocksResponseOK<S> | T>;
    /**
     * The create_doc_block mutation allows you to create a new doc block via the API. You can also specify what fields to query back from the new doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#create-document-block
     * Alternative: Doc.DocBlock.createDocBlock
     * @param options Request options.
     */
    createDocBlock<T = CreateDocBlockFullResponseOK, S extends CreateDocBlockRequest = CreateDocBlockRequest>(options: S): Promise<CreateDocBlockResponseOK<S> | T>;
    /**
     * The update_doc_block mutation allows you to update a doc block via the API. You can also specify what fields to query back from the updated doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#update-document-block
     * Alternative: Doc.DocBlock.updateDocBlock
     * @param options Request options.
     */
    updateDocBlock<T = UpdateDocBlockFullResponseOK, S extends UpdateDocBlockRequest = UpdateDocBlockRequest>(options: S): Promise<UpdateDocBlockResponseOK<S> | T>;
    /**
     * The delete_doc_block mutation allows you to delete a doc block via the API. You can also specify what fields to query back from the deleted doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#delete-document-block
     * Alternative: Doc.DocBlock.deleteDocBlock
     * @param options Request options.
     */
    deleteDocBlock<T = DeleteDocBlockFullResponseOK, S extends DeleteDocBlockRequest = DeleteDocBlockRequest>(options: S): Promise<DeleteDocBlockResponseOK<S> | T>;
    /**
     * Querying tags will return metadata about one or a collection of the account's public tags. Public tags appear on main boards and are accessible to all member
     * and viewer-level users by default, while private tags only appear on private or shareable boards. This method accepts one argument and returns an array.
     * You can query tags directly at the root to return public tags. If you do so and use the ids argument of a private tag, you will get an empty result.
     * To return tags stored on private or shareable boards, you can nest tags within a boards query.
     * Alternative: Tag.getTags
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#queries
     * @param options Request options.
     */
    getTags<T = GetTagsFullResponseOK, S extends GetTagsRequest = GetTagsRequest>(options: S): Promise<GetTagsResponseOK<S> | T>;
    /**
     * The create_or_get_tag mutation allows you to create new tags or receive their data if they already exist via the API.
     * You can also specify what fields to query back from the tag when you run the mutation.
     * Alternative: Tag.createOrGetTag
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#create-or-get-a-tag
     * @param options Request options.
     */
    createOrGetTag<T = CreateOrGetTagResponseOK, S extends CreateOrGetTagRequest = CreateOrGetTagRequest>(options: S): Promise<CreateOrGetTagResponseOK<S> | T>;
    /**
     * Querying version will return metadata about the API version used to make a request. This method does not accept any arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/version#queries
     * Alternative: Version.getVersion
     * @param options Request options.
     */
    getVersion<T = GetVersionFullResponseOK, S extends GetVersionRequest = GetVersionRequest>(options: S): Promise<GetVersionResponseOK<S> | T>;
    /**
     * Querying versions will return metadata about all available API versions. This method does not accept any arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/versions#queries
     * Alternative: Version.getVersions
     * @param options Request options.
     */
    getVersions<T = GetVersionsFullResponseOK, S extends GetVersionsRequest = GetVersionsRequest>(options: S): Promise<GetVersionsResponseOK<S> | T>;
    /**
     * Querying webhooks will return one or a collection of webhooks. This method accepts various arguments and returns an array.
     * You can only query webhooks directly at the root, so it can't be nested within another query.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#queries
     * Alternative: Webhook.getWebhooks
     * @param options
     */
    getWebhooks<T = GetWebhooksFullResponseOK, S extends GetWebhooksRequest = GetWebhooksRequest>(options: S): Promise<GetWebhooksResponseOK<S> | T>;
    /**
     * The create_webhook mutation allows you to create a new webhook via the API. You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, a webhook subscription will be created based on a specific event, so the webhook will send data to the subscribed URL every time the event happens on your board.
     *
     * You can add a query param to your webhook URL if you want to differentiate between subitem and main item events.
     * The URL must pass a verification test where we will send a JSON POST body request containing a challenge field.
     * Monday.com expects your provided URL to return the token as a challenge field in your response JSON body to that request.
     *
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#create-a-webhook
     * Alternative: Webhook.createWebhook
     * @param options
     */
    createWebhook<T = CreateWebhooksFullResponseOK, S extends CreateWebhookRequest = CreateWebhookRequest>(options: S): Promise<CreateWebhookResponseOK<S> | T>;
    /**
     * The delete_webhook mutation allows you to delete a webhook via the API.
     * You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, it will no longer report events to the URL given.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#delete-a-webhook
     * Alternative: Webhook.deleteWebhook
     * @param options
     */
    deleteWebhook<T = DeleteWebhooksFullResponseOK, S extends DeleteWebhookRequest = DeleteWebhookRequest>(options: S): Promise<DeleteWebhookResponseOK<S> | T>;
    /**
     * Querying folders will return metadata about one or a collection of folders. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#queries
     * Alternative: Folder.getFolders
     * @param options Request options.
     */
    getFolders<T = GetFoldersFullResponseOK, S extends GetFoldersRequest = GetFoldersRequest>(options: S): Promise<GetFoldersResponseOK<S> | T>;
    /**
     * The create_folder mutation allows you to create a new folder in a workspace via the API. You can also specify what fields to query back from the new folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#create-a-folder
     * Alternative: Folder.createFolder
     * @param options Request options.
     */
    createFolder<T = CreateFolderFullResponseOK, S extends CreateFolderRequest = CreateFolderRequest>(options: S): Promise<CreateFolderResponseOK<S> | T>;
    /**
     * The update_folder mutation allows you to update a folder's color, name, or parent folder via the API. You can also specify what fields to query back from the updated folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#update-a-folder
     * Alternative: Folder.updateFolder
     * @param options Request options.
     */
    updateFolder<T = UpdateFolderFullResponseOK, S extends UpdateFolderRequest = UpdateFolderRequest>(options: S): Promise<UpdateFolderResponseOK<S> | T>;
    /**
     * The delete_folder mutation allows you to delete and folder and all its contents via the API. You can also specify what fields to query back from the deleted folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#delete-a-folder
     * Alternative: Folder.deleteFolder
     * @param options Request options.
     */
    deleteFolder<T = DeleteFolderFullResponseOK, S extends DeleteFolderRequest = DeleteFolderRequest>(options: S): Promise<DeleteFolderResponseOK<S> | T>;
}
declare class NotificationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * The create_notification mutation allows you to send a notification to the bell icon via the API. Doing so may also send an email if the recipient's email preferences are set up accordingly.
     * Please note that this mutation only sends the notification; you can't query back the notification ID when running the mutation, as notifications are asynchronous.
     * Documentation: https://developer.monday.com/api-reference/docs/notification#create-a-notification
     * @param options Request options.
     */
    createNotification<T = CreateNotificationFullResponseOK, S extends CreateNotificationRequest = CreateNotificationRequest>(options: S): Promise<CreateNotificationResponseOK<S> | T>;
}
declare class TeamGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * The delete_teams_from_workspace mutation allows you to delete teams from a workspace via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-workspace
     * @param options
     */
    deleteTeamsFromWorkspace<T = DeleteTeamsFromWorkspaceFullResponseOK, S extends DeleteTeamsFromWorkspaceRequest = DeleteTeamsFromWorkspaceRequest>(options: S): Promise<DeleteTeamsFromWorkspaceResponseOK<S> | T>;
    /**
     * The delete_teams_from_board mutation allows you to delete teams from a board via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-board
     * @param options
     */
    deleteTeamsFromBoard<T = DeleteTeamsFromBoardFullResponseOK, S extends DeleteTeamsFromBoardRequest = DeleteTeamsFromBoardRequest>(options: S): Promise<DeleteTeamsFromBoardResponseOK<S> | T>;
    /**
     * The add_teams_to_workspace mutation allows you to add teams to a workspace via the API. You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-workspace
     * @param options
     */
    addTeamsToWorkspace<T = AddTeamsToWorkspaceFullResponseOK, S extends AddTeamsToWorkspaceRequest = AddTeamsToWorkspaceRequest>(options: S): Promise<AddTeamsToWorkspaceResponseOK<S> | T>;
    /**
     * The add_teams_to_board mutation allows you to add teams to a board via the API. You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-board
     * @param options
     */
    addTeamsToBoard<T = AddTeamsToBoardFullResponseOK, S extends AddTeamsToBoardRequest = AddTeamsToBoardRequest>(options: S): Promise<AddTeamsToBoardResponseOK<S> | T>;
    /**
     * Querying teams will return metadata about one or several teams. This method accepts one argument and returns an array.
     *
     * You can query teams directly at the root, or you can nest it within a users query to return the teams a specific user is part of. Please note that nesting your query will increase its complexity.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#queries
     * @param options
     */
    getTeams<T = GetTeamsFullResponseOK, S extends GetTeamsRequest = GetTeamsRequest>(options: S): Promise<GetTeamsResponseOK<S> | T>;
    /**
     * The add_users_to_team mutation allows you to add users to a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/reference/users#add-users-to-a-team
     * @param options
     */
    addUsersToTeam<T = AddUsersToTeamFullResponseOK, S extends AddUsersToTeamRequest = AddUsersToTeamRequest>(options: S): Promise<AddUsersToTeamResponseOK<S> | T>;
    /**
     * The remove_users_from_team mutation allows you to remove users from a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/reference/users#remove-users-from-a-team
     * @param options
     */
    removeUsersFromTeam<T = RemoveUsersFromTeamFullResponseOK, S extends RemoveUsersFromTeamRequest = RemoveUsersFromTeamRequest>(options: S): Promise<RemoveUsersFromTeamResponseOK<S> | T>;
}
declare class BoardGroup {
    private implementation;
    private getGlobalErrorStrategy;
    View: BoardViewGroup;
    Group: BoardGroupGroup;
    ItemsPage: BoardItemsPageGroup;
    Tag: BoardTagGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying boards will return metadata about one or a collection of boards. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#queries
     * @param options Request options.
     */
    getBoards<T = GetBoardsFullResponseOK, S extends GetBoardsRequest = GetBoardsRequest>(options: S): Promise<GetBoardsResponseOK<S> | T>;
    /**
     * The create_board mutation allows you to create a new board via the API.
     * You can also specify what fields to query back from the new board when you run the mutation.
     * Please note that the user that creates the board via the API will automatically be added as the board's owner when creating a private or shareable board or if the board_owners_ids argument is missing.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#create-a-board
     * @param options Request options.
     */
    createBoard<T = CreateBoardFullResponseOK, S extends CreateBoardRequest = CreateBoardRequest>(options: S): Promise<CreateBoardResponseOK<S> | T>;
    /**
     * The duplicate_board mutation allows you to duplicate a board with all of its items and groups to a specific workspace or folder of your choice via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#duplicate-a-board
     * @param options Request options.
     */
    duplicateBoard<T = DuplicateBoardFullResponseOK, S extends DuplicateBoardRequest = DuplicateBoardRequest>(options: S): Promise<DuplicateBoardResponseOK<S> | T>;
    /**
     * The update_board mutation allows you to update a board via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#update-a-board
     * @param options Request options.
     */
    updateBoard<T = UpdateBoardFullResponseOK>(options: UpdateBoardRequest): Promise<UpdateBoardResponseOK | T>;
    /**
     * The archive_board mutation allows you to archive a board via the API. You can also specify what fields to query back from the archived board when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#archive-a-board
     * @param options Request options.
     */
    archiveBoard<T = ArchiveBoardFullResponseOK, S extends ArchiveBoardRequest = ArchiveBoardRequest>(options: S): Promise<ArchiveBoardResponseOK<S> | T>;
    /**
     * The delete_board mutation allows you to delete a board via the API. You can also specify what fields to query back from the deleted board when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-a-board
     * @param options Request options.
     */
    deleteBoard<T = DeleteBoardFullResponseOK, S extends DeleteBoardRequest = DeleteBoardRequest>(options: S): Promise<DeleteBoardResponseOK<S> | T>;
    /**
     * The delete_subscribers_from_board mutation allows you to delete subscribers from a board via the API. You can also specify what fields to query back from the subscribers you delete from the board when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-subscribers-from-a-board
     * @param options Request options.
     */
    deleteSubscribersFromBoard<T = DeleteSubscribersBoardFullResponseOK, S extends DeleteSubscribersBoardRequest = DeleteSubscribersBoardRequest>(options: S): Promise<DeleteSubscribersBoardResponseOK<S> | T>;
}
declare class BoardGroupGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * The update_group mutation allows you to update an existing group via the API. You can also specify what fields to query back from the updated group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#update-a-group
     * @param options
     */
    updateGroup<T = UpdateBoardGroupFullResponseOK, S extends UpdateBoardGroupRequest = UpdateBoardGroupRequest>(options: S): Promise<UpdateBoardGroupResponseOK<S> | T>;
    /**
     * The duplicate_group mutation allows you to duplicate a group with all of its items via the API. You can also specify what fields to query back from the duplicated group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#duplicate-group
     * (!) Mutation-specific rate limit:
     * The duplicate_group mutation has an additional rate limit of 40 mutations per minute. If you exceed this limit, you will receive a response with a 429 status code, and the following error message: "Call limit exceeded for DuplicateGroup".
     * @param options
     */
    duplicateGroup<T = DuplicateBoardGroupFullResponseOK, S extends DuplicateBoardGroupRequest = DuplicateBoardGroupRequest>(options: S): Promise<DuplicateBoardGroupResponseOK<S> | T>;
    /**
     * The archive_group mutation allows you to archive a group with all of its items via the API. You can also specify what fields to query back from the archived group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#archive-a-group
     * @param options
     */
    archiveGroup<T = ArchiveBoardGroupFullResponseOK, S extends ArchiveBoardGroupRequest = ArchiveBoardGroupRequest>(options: S): Promise<ArchiveBoardGroupResponseOK<S> | T>;
    /**
     * The delete_group mutation allows you to delete a group with all of its items via the API. You can also specify what fields to query back from the deleted group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#delete-a-group
     * @param options
     */
    deleteGroup<T = DeleteBoardGroupFullResponseOK, S extends DeleteBoardGroupRequest = DeleteBoardGroupRequest>(options: S): Promise<DeleteBoardGroupResponseOK<S> | T>;
    /**
     * The create_group mutation allows you to create a new empty group via the API. You can also specify what fields to query back from the new group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#create-a-group
     * @param options
     */
    createGroup<T = CreateBoardGroupFullResponseOK, S extends CreateBoardGroupRequest = CreateBoardGroupRequest>(options: S): Promise<CreateBoardGroupResponseOK<S> | T>;
    /**
     * Querying groups will return metadata about one or a collection of groups on a specific board. This method accepts one argument and returns an array.	 *
     * You can only query groups by nesting it within another query, so it can't be used at the root.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#queries
     * @param options Request options.
     */
    getGroups<T = GetBoardGroupsFullResponseOK, S extends GetBoardGroupsRequest = GetBoardGroupsRequest>(options: S): Promise<GetBoardGroupsResponseOK<S> | T>;
}
declare class BoardViewGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying views will return a collection of board views from a specific board. This method accepts various arguments and returns an array.
     * You can only query views by nesting it within a boards query, so it can't be used at the root.
     * Documentation: https://developer.monday.com/api-reference/docs/board-view-queries#queries
     * @param options Request options.
     */
    getViews<T = GetBoardViewsFullResponseOK, S extends GetBoardViewsRequest = GetBoardViewsRequest>(options: S): Promise<GetBoardViewsResponseOK<S> | T>;
}
declare class ItemGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Subitem: ItemSubitemGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying items will return metadata about one or a collection of items. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/items#queries
     * @param options Request options.
     */
    getItems<T = GetItemsFullResponseOK, S extends GetItemsRequest = GetItemsRequest>(options: S): Promise<GetItemsResponseOK<S> | T>;
    /**
     * The create_item mutation allows you to create a new item via the API. You can also specify what fields to query back from the new item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#create-an-item
     * @param options Request options.
     */
    createItem<T = CreateItemFullResponseOK, S extends CreateItemRequest = CreateItemRequest>(options: S): Promise<CreateItemResponseOK<S> | T>;
    /**
     * The duplicate_item mutation allows you to duplicate a single item via the API. You can also specify what fields to query back from the duplicated item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#duplicate-an-item
     * @param options Request options.
     */
    duplicateItem<T = DuplicateItemFullResponseOK, S extends DuplicateItemRequest = DuplicateItemRequest>(options: S): Promise<DuplicateItemResponseOK<S> | T>;
    /**
     * The move_item_to_group mutation allows you to move an item between groups on the same board via the API. You can also specify what fields to query back from the item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-group
     * @param options Request options.
     */
    moveItemToGroup<T = MoveItemToGroupFullResponseOK, S extends MoveItemToGroupRequest = MoveItemToGroupRequest>(options: S): Promise<MoveItemToGroupResponseOK<S> | T>;
    /**
     * The move_item_to_board mutation allows you to move an item to another board via the API. You can also specify what fields to query back from the item moved when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-board
     * @param options Request options.
     */
    moveItemToBoard<T = MoveItemToBoardFullResponseOK, S extends MoveItemToBoardRequest = MoveItemToBoardRequest>(options: S): Promise<MoveItemToBoardResponseOK<S> | T>;
    /**
     * The archive_item mutation allows you to archive a single item via the API. You can also specify what fields to query back from the archived item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#archive-an-item
     * @param options Request options.
     */
    archiveItem<T = ArchiveItemFullResponseOK, S extends ArchiveItemRequest = ArchiveItemRequest>(options: S): Promise<ArchiveItemResponseOK<S> | T>;
    /**
     * The delete_item mutation allows you to delete a single item via the API. You can also specify what fields to query back from the deleted item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#delete-an-item
     * @param options Request options.
     */
    deleteItem<T = DeleteItemFullResponseOK, S extends DeleteItemRequest = DeleteItemRequest>(options: S): Promise<DeleteItemResponseOK<S> | T>;
    /**
     * The clear_item_updates mutation allows you to clear all updates on a specific item, including replies and likes. You can also specify what fields to query back from the item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#clear-an-items-updates
     * @param options Request options.
     */
    clearUpdates<T = ClearItemUpdatesFullResponseOK, S extends ClearItemUpdatesRequest = ClearItemUpdatesRequest>(options: S): Promise<ClearItemUpdatesResponseOK<S> | T>;
}
declare class BoardItemsPageGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying items_page will return items filtered by the specified criteria. This method accepts various arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#queries
     * @param options Request options.
     */
    getItemsPage<T = GetItemsPageFullResponseOK, S extends GetItemsPageRequest = GetItemsPageRequest>(options: S): Promise<GetItemsPageResponseOK<S> | T>;
}
declare class BoardTagGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying tags will return metadata about one or a collection of the account's public tags. Public tags appear on main boards and are accessible to all member
     * and viewer-level users by default, while private tags only appear on private or shareable boards. This method accepts no arguments and returns an array.
     * You can query tags directly at the root to return public tags. If you do so and use the ids argument of a private tag, you will get an empty result.
     * To return tags stored on private or shareable boards, you can use this managed API, which is nested within a boards query.
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#queries
     * @param options Request options.
     */
    getTags<T = GetBoardTagsFullResponseOK, S extends GetBoardTagsRequest = GetBoardTagsRequest>(options: S): Promise<GetBoardTagsResponseOK<S> | T>;
}
declare class ItemsPageGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying next_items_page will return the next set of items that correspond with the provided cursor. This method accepts various arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#cursor-based-pagination-using-next_items_page
     * @param options Request options.
     */
    getNextItemsPage<T = GetNextItemsPageFullResponseOK, S extends GetNextItemsPageRequest = GetNextItemsPageRequest>(options: S): Promise<GetNextItemsPageResponseOK<S> | T>;
    /**
     * Querying items_page_by_column_values will search for items based on predefined column values and return metadata about these specific items. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/items-page-by-column-values
     * @param options Request options.
     */
    getItemsPageByColumnValues<T = GetItemsPageByColumnValuesFullResponseOK, S extends GetItemsPageByColumnValuesRequest = GetItemsPageByColumnValuesRequest>(options: S): Promise<GetItemsPageByColumnValuesResponseOK<S> | T>;
}
declare class ItemSubitemGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying subitems will return metadata about one or a collection of subitems. This method does not accept any arguments and returns an array.
     * You can only query subitems by nesting it within another query, so it can't be used at the root.
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#queries
     * @param options Request options.
     */
    getSubitems<T = GetSubitemsFullResponseOK, S extends GetSubitemsRequest = GetSubitemsRequest>(options: S): Promise<GetSubitemsResponseOK<S> | T>;
    /**
     * The create_subitem mutation allows you to create a new subitem via the API. You can also specify what fields to query back from the new subitem when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#create-a-subitem
     * @param options Request options.
     */
    createSubitem<T = CreateSubitemFullResponseOK, S extends CreateSubitemRequest = CreateSubitemRequest>(options: S): Promise<CreateSubitemResponseOK<S> | T>;
}
declare class MeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying me will return metadata about the user whose API key is being used. This method does not accept any arguments and returns an object.
     * You can only query me directly at the root, so it can't be nested within another query.
     * Documentation: https://developer.monday.com/api-reference/docs/me#queries
     * @param options Request options.
     */
    getUserDetails<T = GetUserDetailsFullResponseOK, S extends GetUserDetailsRequest = GetUserDetailsRequest>(options: S): Promise<GetUserDetailsResponseOK<S> | T>;
}
declare class UserGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying users will return metadata about one or multiple users. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/users#queries
     * @param options Request options.
     */
    getUsers<T = GetUsersFullResponseOK, S extends GetUsersRequest = GetUsersRequest>(options: S): Promise<GetUsersResponseOK<S> | T>;
    /**
     * The add_users_to_board mutation allows you to add users to a board via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-board
     * @param options Request options.
     */
    addUsersToBoard<T = AddUsersToBoardFullResponseOK, S extends AddUsersToBoardRequest = AddUsersToBoardRequest>(options: S): Promise<AddUsersToBoardResponseOK<S> | T>;
    /**
     * The add_users_to_workspace mutation allows you to add users to a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-workspace
     * @param options Request options.
     */
    addUsersToWorkspace<T = AddUsersToWorkspaceFullResponseOK, S extends AddUsersToWorkspaceRequest = AddUsersToWorkspaceRequest>(options: S): Promise<AddUsersToWorkspaceResponseOK<S> | T>;
    /**
     * The delete_users_from_workspace mutation allows you to delete users from a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/users#delete-users-from-a-workspace
     * @param options Request options.
     */
    deleteUsersFromWorkspace<T = DeleteUsersFromWorkspaceFullResponseOK, S extends DeleteUsersFromWorkspaceRequest = DeleteUsersFromWorkspaceRequest>(options: S): Promise<DeleteUsersFromWorkspaceResponseOK<S> | T>;
}
declare class FileGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying assets will return one or a collection of assets. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/files#queries
     * @param options Request options.
     */
    getAssets<T = GetAssetsFullResponseOK, S extends GetAssetsRequest = GetAssetsRequest>(options: S): Promise<GetAssetsResponseOK<S> | T>;
    /**
     * The add_file_to_update mutation allows you to add a file to an update via the API. You can also specify what fields to query back when you run the mutation. Please note that the file will be added to the bottom of the update.
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-a-file-to-an-update
     * @param options Request options.
     */
    addFileToUpdate<T = AddFileToUpdateFullResponseOK, S extends AddFileToUpdateRequest = AddFileToUpdateRequest>(options: S): Promise<AddFileToUpdateResponseOK<S> | T>;
    /**
     * The add_file_to_column mutation will add a file to the file column of a specific item. You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-file-to-the-file-column
     * @param options Request options.
     */
    addFileToColumn<T = AddFileToColumnFullResponseOK, S extends AddFileToColumnRequest = AddFileToColumnRequest>(options: S): Promise<AddFileToColumnResponseOK<S> | T>;
}
declare class ColumnGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * The create_column mutation allows you to create a new column on a board within the account via the API.
     * The create_column mutation also allows you to create a new status or dropdown column with custom labels via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#create-a-column
     * @param options Request options.
     */
    createColumn<T = CreateColumnFullResponseOK, S extends CreateColumnRequest = CreateColumnRequest>(options: S): Promise<CreateColumnResponseOK<S> | T>;
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-value
     * @param options Request options.
     */
    changeColumnValue<T = ChangeColumnValueFullResponseOK, S extends ChangeColumnValueRequest = ChangeColumnValueRequest>(options: S): Promise<ChangeColumnValueResponseOK<S> | T>;
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item with a string value.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-simple-column-value
     * @param options Request options.
     */
    changeSimpleColumnValue<T = ChangeSimpleColumnValueFullResponseOK, S extends ChangeSimpleColumnValueRequest = ChangeSimpleColumnValueRequest>(options: S): Promise<ChangeSimpleColumnValueResponseOK<S> | T>;
    /**
     * The change_multiple_column_values mutation allows you to change multiple column values of a specific item.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-multiple-column-values
     * @param options Request options.
     */
    changeMultipleColumnValues<T = ChangeMultipleColumnValuesFullResponseOK, S extends ChangeMultipleColumnValuesRequest = ChangeMultipleColumnValuesRequest>(options: S): Promise<ChangeMultipleColumnValuesResponseOK<S> | T>;
    /**
     * The change_column_title mutation allows you to change the title of an existing column via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-title
     * @param options Request options.
     */
    changeColumnTitle<T = ChangeColumnTitleFullResponseOK, S extends ChangeColumnTitleRequest = ChangeColumnTitleRequest>(options: S): Promise<ChangeColumnTitleResponseOK<S> | T>;
    /**
     * The change_column_metadata mutation allows you to update the metadata of an existing column.
     * Currently, we support updating both the title and description.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-column-metadata
     * @param options Request options.
     */
    changeColumnMetadata<T = ChangeColumnMetadataFullResponseOK, S extends ChangeColumnMetadataRequest = ChangeColumnMetadataRequest>(options: S): Promise<ChangeColumnMetadataResponseOK<S> | T>;
    /**
     * The delete_column mutation allows you to delete a single column from a board via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#delete-a-column
     * @param options Request options.
     */
    deleteColumn<T = DeleteColumnFullResponseOK, S extends DeleteColumnRequest = DeleteColumnRequest>(options: S): Promise<DeleteColumnResponseOK<S> | T>;
}
declare class WorkspaceGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying workspaces will return metadata about one or a collection of workspaces.
     * This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#queries
     * @param options Request options.
     */
    getWorkspaces<T = GetWorkspacesFullResponseOK, S extends GetWorkspacesRequest = GetWorkspacesRequest>(options: S): Promise<GetWorkspacesResponseOK<S> | T>;
    /**
     * The create_workspace mutation allows you to create a new workspace via the API.
     * You can also specify what fields to query back from the new workspace when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#create-a-workspace
     * @param options Request options.
     */
    createWorkspace<T = CreateWorkspaceFullResponseOK, S extends CreateWorkspaceRequest = CreateWorkspaceRequest>(options: S): Promise<CreateWorkspaceResponseOK<S> | T>;
    /**
     * The update_workspace mutation allows you to update a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/reference/workspaces#update-a-workspace
     * @param options Request options.
     */
    updateWorkspace<T = UpdateWorkspaceFullResponseOK, S extends UpdateWorkspaceRequest = UpdateWorkspaceRequest>(options: S): Promise<UpdateWorkspaceResponseOK<S> | T>;
    /**
     * The delete_workspace mutation allows you to delete a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#delete-a-column
     * @param options Request options.
     */
    deleteWorkspace<T = DeleteWorkspaceFullResponseOK, S extends DeleteWorkspaceRequest = DeleteWorkspaceRequest>(options: S): Promise<DeleteWorkspaceResponseOK<S> | T>;
}
declare class FolderGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying folders will return metadata about one or a collection of folders. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#queries
     * @param options Request options.
     */
    getFolders<T = GetFoldersFullResponseOK, S extends GetFoldersRequest = GetFoldersRequest>(options: S): Promise<GetFoldersResponseOK<S> | T>;
    /**
     * The create_folder mutation allows you to create a new folder in a workspace via the API. You can also specify what fields to query back from the new folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#create-a-folder
     * @param options Request options.
     */
    createFolder<T = CreateFolderFullResponseOK, S extends CreateFolderRequest = CreateFolderRequest>(options: S): Promise<CreateFolderResponseOK<S> | T>;
    /**
     * The update_folder mutation allows you to update a folder's color, name, or parent folder via the API. You can also specify what fields to query back from the updated folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#update-a-folder
     * @param options Request options.
     */
    updateFolder<T = UpdateFolderFullResponseOK, S extends UpdateFolderRequest = UpdateFolderRequest>(options: S): Promise<UpdateFolderResponseOK<S> | T>;
    /**
     * The delete_folder mutation allows you to delete and folder and all its contents via the API. You can also specify what fields to query back from the deleted folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#delete-a-folder
     * @param options Request options.
     */
    deleteFolder<T = DeleteFolderFullResponseOK, S extends DeleteFolderRequest = DeleteFolderRequest>(options: S): Promise<DeleteFolderResponseOK<S> | T>;
}
declare class UpdateGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying updates will return metadata about one or a collection of updates.
     * This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#queries
     * @param options Request options.
     */
    getUpdates<T = GetUpdatesFullResponseOK, S extends GetUpdatesRequest = GetUpdatesRequest>(options: S): Promise<GetUpdatesResponseOK<S> | T>;
    /**
     * The create_update mutation allows you to add an update to an item via the API.
     * You can also specify what fields to query back from the new update when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#create-an-update
     * @param options Request options.
     */
    createUpdate<T = CreateUpdateFullResponseOK, S extends CreateUpdateRequest = CreateUpdateRequest>(options: S): Promise<CreateUpdateResponseOK<S> | T>;
    /**
     * The delete_update mutation allows you to delete an item's update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#delete-an-update
     * @param options Request options.
     */
    deleteUpdate<T = DeleteUpdateFullResponseOK, S extends DeleteUpdateRequest = DeleteUpdateRequest>(options: S): Promise<DeleteUpdateResponseOK<S> | T>;
    /**
     * The like_update mutation allows you to like an update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#like-an-update
     * @param options Request options.
     */
    likeUpdate<T = LikeUpdateFullResponseOK, S extends LikeUpdateRequest = LikeUpdateRequest>(options: S): Promise<LikeUpdateResponseOK<S> | T>;
}
declare class DocGroup {
    private implementation;
    private getGlobalErrorStrategy;
    DocBlock: DocBlockGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying docs will return metadata about a collection of docs. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#queries
     * @param options Request options.
     */
    getDocs<T = GetDocsFullResponseOK, S extends GetDocsRequest = GetDocsRequest>(options: S): Promise<GetDocsResponseOK<S> | T>;
    /**
     * The create_doc mutation allows you to create a new doc in a document column or workspace via the API. You can also specify what fields to query back from the new doc when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#create-a-doc
     * @param options Request options.
     */
    createDoc<T = CreateDocFullResponseOK, S extends CreateDocRequest = CreateDocRequest>(options: S): Promise<CreateDocResponseOK<S> | T>;
}
declare class DocBlockGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying blocks will return metadata about one or a collection of blocks. The method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#queries
     * @param options Request options.
     */
    getDocBlocks<T = GetDocBlocksFullResponseOK, S extends GetDocBlocksRequest = GetDocBlocksRequest>(options: S): Promise<GetDocBlocksResponseOK<S> | T>;
    /**
     * The create_doc_block mutation allows you to create a new doc block via the API. You can also specify what fields to query back from the new doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#create-document-block
     * @param options Request options.
     */
    createDocBlock<T = CreateDocBlockFullResponseOK, S extends CreateDocBlockRequest = CreateDocBlockRequest>(options: S): Promise<CreateDocBlockResponseOK<S> | T>;
    /**
     * The update_doc_block mutation allows you to update a doc block via the API. You can also specify what fields to query back from the updated doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#update-document-block
     * @param options Request options.
     */
    updateDocBlock<T = UpdateDocBlockFullResponseOK, S extends UpdateDocBlockRequest = UpdateDocBlockRequest>(options: S): Promise<UpdateDocBlockResponseOK<S> | T>;
    /**
     * The delete_doc_block mutation allows you to delete a doc block via the API. You can also specify what fields to query back from the deleted doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#delete-document-block
     * @param options Request options.
     */
    deleteDocBlock<T = DeleteDocBlockFullResponseOK, S extends DeleteDocBlockRequest = DeleteDocBlockRequest>(options: S): Promise<DeleteDocBlockResponseOK<S> | T>;
}
declare class TagGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying tags will return metadata about one or a collection of the account's public tags. Public tags appear on main boards and are accessible to all member
     * and viewer-level users by default, while private tags only appear on private or shareable boards. This method accepts one argument and returns an array.
     * You can query tags directly at the root to return public tags. If you do so and use the ids argument of a private tag, you will get an empty result.
     * To return tags stored on private or shareable boards, you can nest tags within a boards query.
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#queries
     * @param options Request options.
     */
    getTags<T = GetTagsFullResponseOK, S extends GetTagsRequest = GetTagsRequest>(options: S): Promise<GetTagsResponseOK<S> | T>;
    /**
     * The create_or_get_tag mutation allows you to create new tags or receive their data if they already exist via the API.
     * You can also specify what fields to query back from the tag when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#create-or-get-a-tag
     * @param options Request options.
     */
    createOrGetTag<T = CreateOrGetTagResponseOK, S extends CreateOrGetTagRequest = CreateOrGetTagRequest>(options: S): Promise<CreateOrGetTagResponseOK<S> | T>;
}
declare class VersionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying version will return metadata about the API version used to make a request. This method does not accept any arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/version#queries
     * @param options Request options.
     */
    getVersion<T = GetVersionFullResponseOK, S extends GetVersionRequest = GetVersionRequest>(options: S): Promise<GetVersionResponseOK<S> | T>;
    /**
     * Querying versions will return metadata about all available API versions. This method does not accept any arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/versions#queries
     * @param options Request options.
     */
    getVersions<T = GetVersionsFullResponseOK, S extends GetVersionsRequest = GetVersionsRequest>(options: S): Promise<GetVersionsResponseOK<S> | T>;
}
declare class WebhookGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Querying webhooks will return one or a collection of webhooks. This method accepts various arguments and returns an array.
     * You can only query webhooks directly at the root, so it can't be nested within another query.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#queries
     * @param options
     */
    getWebhooks<T = GetWebhooksFullResponseOK, S extends GetWebhooksRequest = GetWebhooksRequest>(options: S): Promise<GetWebhooksResponseOK<S> | T>;
    /**
     * The create_webhook mutation allows you to create a new webhook via the API. You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, a webhook subscription will be created based on a specific event, so the webhook will send data to the subscribed URL every time the event happens on your board.
     *
     * You can add a query param to your webhook URL if you want to differentiate between subitem and main item events.
     * The URL must pass a verification test where we will send a JSON POST body request containing a challenge field.
     * Monday.com expects your provided URL to return the token as a challenge field in your response JSON body to that request.
     *
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#create-a-webhook
     * @param options
     */
    createWebhook<T = CreateWebhooksFullResponseOK, S extends CreateWebhookRequest = CreateWebhookRequest>(options: S): Promise<CreateWebhookResponseOK<S> | T>;
    /**
     * The delete_webhook mutation allows you to delete a webhook via the API.
     * You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, it will no longer report events to the URL given.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#delete-a-webhook
     * @param options
     */
    deleteWebhook<T = DeleteWebhooksFullResponseOK, S extends DeleteWebhookRequest = DeleteWebhookRequest>(options: S): Promise<DeleteWebhookResponseOK<S> | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map