/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { AssetFields, AssetReturnType, SelectAssetReturnType } from '../definitions/asset';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetAssetsRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * Ids of the assets/files you want to get
         */
        ids: number[];
    };
    fields: AssetFields;
    complexity?: ComplexityFields;
}
export interface GetAssetsResponseOK<S extends GetAssetsRequest = GetAssetsRequest> {
    data: {
        assets: Array<SelectAssetReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetAssetsFullResponseOK {
    data: {
        assets: AssetReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddFileToUpdateRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The update to add the file to.
         */
        update_id: number;
        /**
         * The file to upload.
         */
        file: {
            fileName: string;
            content: string | ArrayBuffer;
        };
    };
    fields: AssetFields;
    complexity?: ComplexityFields;
}
export interface AddFileToUpdateResponseOK<S extends AddFileToUpdateRequest = AddFileToUpdateRequest> {
    data: {
        add_file_to_update: SelectAssetReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddFileToUpdateFullResponseOK {
    data: {
        add_file_to_update: AssetReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddFileToColumnRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The item to add the file to.
         */
        item_id: number;
        /**
         * The column to add the file to.
         */
        column_id: string;
        /**
         * The file to upload.
         */
        file: {
            fileName: string;
            content: string | ArrayBuffer;
        };
    };
    fields: AssetFields;
    complexity?: ComplexityFields;
}
export interface AddFileToColumnResponseOK<S extends AddFileToColumnRequest = AddFileToColumnRequest> {
    data: {
        add_file_to_column: SelectAssetReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddFileToColumnFullResponseOK {
    data: {
        add_file_to_column: AssetReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=assets.d.ts.map