/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { ErrorStrategyOption } from '../errorStrategy';
import { DocsFields, SelectDocsReturnType, DocsReturnType } from '../definitions/doc';
import { ID } from './id';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetDocsRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The specific docs to return.
         */
        ids?: number[];
        /**
         * The unique identifiers of associated boards or objects. This is the same ID in the URL and the doc column values.
         */
        object_ids?: number[];
        /**
         * The order in which to retrieve your boards: created_at or used_at. The default shows created_at with the newest docs listed first.
         * This argument will not be applied if you query docs by specific ids.
         */
        order_by?: DocsOrderBy;
        /**
         * The unique identifiers of the specific workspaces to return.
         */
        workspace_ids?: number[];
        /**
         * Number of items to get, the default is 25.
         */
        limit?: number;
        /**
         * Page number to get, starting at 1.
         */
        page?: number;
    };
    fields: DocsFields;
    complexity?: ComplexityFields;
}
export declare type DocsOrderBy = 'created_at' | 'used_at';
export interface GetDocsResponseOK<S extends GetDocsRequest = GetDocsRequest> {
    data: {
        docs: Array<SelectDocsReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetDocsFullResponseOK {
    data: {
        docs: DocsReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateDocRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The new document's location. This can either be a board or a workspace.
         */
        location: CreateDocInput;
    };
    fields: DocsFields;
    complexity?: ComplexityFields;
}
export declare type CreateDocInput = CreateDocInputForBoard | CreateDocInputForWorkspace;
export interface CreateDocInputForBoard {
    /**
     * The new document's location (when creating a doc on a board).
     */
    board: CreateDocBoardInput;
    workspace?: never;
}
export interface CreateDocBoardInput {
    /**
     * The unique identifier of the column to create the new doc in.
     */
    column_id: string;
    /**
     * The unique identifier of the item to create the new doc on.
     */
    item_id: ID;
}
export interface CreateDocInputForWorkspace {
    /**
     * The new document's location (when creating a doc in a workspace).
     */
    workspace: CreateDocWorkspaceInput;
    board?: never;
}
export interface CreateDocWorkspaceInput {
    /**
     * The kind of document to create: public, private, or share. Default is public.
     */
    kind?: 'public' | 'private' | 'share';
    /**
     * The new document's name.
     */
    name: string;
    /**
     * The unique identifier of the workspace to create the new doc in.
     */
    workspace_id: number;
}
export interface CreateDocResponseOK<S extends CreateDocRequest = CreateDocRequest> {
    data: {
        docs: Array<SelectDocsReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateDocFullResponseOK {
    data: {
        docs: DocsReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=doc.d.ts.map