/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { DocBlockFields as DocBlockFields, DocBlockReturnType, GetDocBlockFields, SelectDocBlockReturnType as SelectDocBlockReturnType } from '../definitions/docBlock';
import { ErrorStrategyOption } from '../errorStrategy';
import { DocsOrderBy } from './doc';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetDocBlocksRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The specific docs to return.
         */
        ids?: number[];
        /**
         * The unique identifiers of associated boards or objects. This is the same ID in the URL and the doc column values.
         */
        object_ids?: number[];
        /**
         * The order in which to retrieve your boards: created_at or used_at. The default shows created_at with the newest docs listed first.
         * This argument will not be applied if you query docs by specific ids.
         */
        order_by?: DocsOrderBy;
        /**
         * The unique identifiers of the specific workspaces to return.
         */
        workspace_ids?: number[];
        /**
         * Number of items to get, the default is 25.
         */
        limit?: number;
        /**
         * Page number to get, starting at 1.
         */
        page?: number;
    };
    fields: GetDocBlockFields;
    complexity?: ComplexityFields;
}
export interface GetDocBlocksResponseOK<S extends GetDocBlocksRequest = GetDocBlocksRequest> {
    data: {
        docs: Array<SelectDocBlockReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetDocBlocksFullResponseOK {
    data: {
        docs: DocBlockReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateDocBlockRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The block's ID that will be above the new block. Used to specify where in the doc the new block should go.
         * Without this argument, the new block will appear at the top of the doc.
         */
        after_block_id?: string;
        /**
         * The document's unique identifier.
         */
        doc_id: number;
        /**
         * The block's content type: normal_text, large_title, medium_title, small_title, quote, bulleted_list, numbered_list, check_list, or code.
         */
        type: DocBlockContentType;
        /**
         * The block's content. See https://developer.monday.com/api-reference/docs/blocks#content-field
         */
        content: string;
    };
    fields: DocBlockFields;
    complexity?: ComplexityFields;
}
export declare type DocBlockContentType = 'normal_text' | 'large_title' | 'medium_title' | 'small_title' | 'quote' | 'bulleted_list' | 'numbered_list' | 'check_list' | 'code';
export interface CreateDocBlockResponseOK<S extends CreateDocBlockRequest = CreateDocBlockRequest> {
    data: {
        create_doc_block: Array<SelectDocBlockReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateDocBlockFullResponseOK {
    data: {
        create_doc_block: DocBlockReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateDocBlockRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The block's unique identifier.
         */
        block_id: string;
        /**
         * The block's content. See https://developer.monday.com/api-reference/docs/blocks#content-field
         */
        content: string;
    };
    fields: DocBlockFields;
    complexity?: ComplexityFields;
}
export interface UpdateDocBlockResponseOK<S extends UpdateDocBlockRequest = UpdateDocBlockRequest> {
    data: {
        update_doc_block: Array<SelectDocBlockReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateDocBlockFullResponseOK {
    data: {
        update_doc_block: DocBlockReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteDocBlockRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The block's unique identifier.
         */
        block_id: string;
    };
    fields: DocBlockFields;
    complexity?: ComplexityFields;
}
export interface DeleteDocBlockResponseOK<S extends DeleteDocBlockRequest = DeleteDocBlockRequest> {
    data: {
        delete_doc_block: Array<SelectDocBlockReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteDocBlockFullResponseOK {
    data: {
        delete_doc_block: DocBlockReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=docBlock.d.ts.map