/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { ItemFields, ItemReturnType, SelectItemReturnType } from '../definitions/item';
import { SelectSubitemReturnType, SubitemFields } from '../definitions/subitem';
import { GetItemsRequest } from './item';
import { ErrorStrategyOption } from '../errorStrategy';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetSubitemsRequest extends GetItemsRequest {
    fields: SubitemFields;
    complexity?: ComplexityFields;
}
export interface GetSubitemsResponseOK<S extends GetSubitemsRequest = GetSubitemsRequest> {
    data: {
        items: Array<SelectSubitemReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetSubitemsFullResponseOK {
    data: {
        items: ItemReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateSubitemRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The parent item's unique identifier.
         */
        parent_item_id: number;
        /**
         * The new item's name.
         */
        item_name: string;
        /**
         * The column values of the new item.
         */
        column_values?: Record<string, any>;
        /**
         * Create Status/Dropdown labels if they're missing. (Requires permission to change board structure)
         */
        create_labels_if_missing?: boolean;
    };
    fields: ItemFields;
    complexity?: ComplexityFields;
}
export interface CreateSubitemResponseOK<S extends CreateSubitemRequest = CreateSubitemRequest> {
    data: {
        create_subitem: SelectItemReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateSubitemFullResponseOK {
    data: {
        create_subitem: ItemReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=subitem.d.ts.map