import { HeadersOption } from '@managed-api/commons-core';
import { TagFields, SelectTagReturnType, TagReturnType, BoardTagFields } from '../definitions/tag';
import { ErrorStrategyOption } from '../errorStrategy';
import { BoardKind } from '../definitions/board';
import { State } from '../definitions/workspace';
import { ID } from './id';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetTagsRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The unique identifiers of the specific tags to return.
         */
        ids?: number[];
    };
    fields: TagFields;
    complexity?: ComplexityFields;
}
export interface GetTagsResponseOK<S extends GetTagsRequest = GetTagsRequest> {
    data: {
        tags: Array<SelectTagReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetTagsFullResponseOK {
    data: {
        tags: TagReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateOrGetTagRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifier of the shareable or private board where the tag should be created. This argument is not required for main boards.
         */
        board_id?: number;
        /**
         * The new tag's name.
         */
        tag_name: string;
    };
    fields: TagFields;
    complexity?: ComplexityFields;
}
export interface CreateOrGetTagResponseOK<S extends CreateOrGetTagRequest = CreateOrGetTagRequest> {
    data: {
        create_or_get_tag: Array<SelectTagReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateOrGetTagFullResponseOK {
    data: {
        create_or_get_tag: TagReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardTagsRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The board's kind (public / private / share)
         */
        board_kind?: BoardKind;
        /**
         * A list of boards unique identifiers.
         */
        ids?: ID[];
        /**
         * Number of items to get, the default is 25.
         */
        limit?: number;
        /**
         * Property to order by (created_at / used_at).
         */
        order_by?: 'created_at' | 'used_at';
        /**
         * Page number to get, starting at 1.
         */
        page?: number;
        /**
         * The state of the board (all / active / archived / deleted), the default is active.
         */
        state?: State;
        /**
         * A list of workspace ids the boards are contained in.
         */
        workspace_ids?: number[];
    };
    fields: BoardTagFields;
    complexity?: ComplexityFields;
}
export interface GetBoardTagsResponseOK<S extends GetBoardTagsRequest = GetBoardTagsRequest> {
    data: {
        tags: Array<SelectTagReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardTagsFullResponseOK {
    data: {
        tags: TagReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=tag.d.ts.map