/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { SelectUserReturnType, UserFields, UserKind, UserReturnType } from '../definitions/user';
import { BoardSubscriberKind } from '../definitions/board';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetUsersRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * A list of users' unique identifiers.
         */
        ids?: number[];
        /**
         * The kind to search users by (all / non_guests / guests / non_pending).
         */
        kind?: UserKind;
        /**
         * Get the recently created users at the top of the list.
         */
        newest_first?: boolean;
        /**
         * A list of users' emails.
         */
        emails?: string[];
        /**
         * Allows to fuzzy search by name
         */
        name?: string;
        /**
         * Return non active users in the account.
         */
        non_active?: boolean;
        /**
         * Number of users to get.
         */
        limit?: number;
        /**
         * Page number to get, starting at 1.
         */
        page?: number;
    };
    fields: UserFields;
    complexity?: ComplexityFields;
}
export interface GetUsersResponseOK<S extends GetUsersRequest = GetUsersRequest> {
    data: {
        users: Array<SelectUserReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetUsersFullResponseOK {
    data: {
        users: UserReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddUsersToBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: number;
        /**
         * User ids to subscribe to a board
         */
        user_ids: number[];
        /**
         * Subscribers kind (subscriber / owner)
         */
        kind?: BoardSubscriberKind;
    };
    fields: UserFields;
    complexity?: ComplexityFields;
}
export interface AddUsersToBoardResponseOK<S extends AddUsersToBoardRequest = AddUsersToBoardRequest> {
    data: {
        add_users_to_board: Array<SelectUserReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddUsersToBoardFullResponseOK {
    data: {
        add_users_to_board: UserReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddUsersToWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The workspace's unique identifier.
         */
        workspace_id: number;
        /**
         * User ids to subscribe to a board
         */
        user_ids: number[];
        /**
         * Subscribers kind (subscriber / owner)
         */
        kind?: BoardSubscriberKind;
    };
    fields: UserFields;
    complexity?: ComplexityFields;
}
export interface AddUsersToWorkspaceResponseOK<S extends AddUsersToWorkspaceRequest = AddUsersToWorkspaceRequest> {
    data: {
        add_users_to_workspace: Array<SelectUserReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddUsersToWorkspaceFullResponseOK {
    data: {
        add_users_to_workspace: UserReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteUsersFromWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The workspace's unique identifier.
         */
        workspace_id: number;
        /**
         * User ids to subscribe to a board
         */
        user_ids: number[];
    };
    fields: UserFields;
    complexity?: ComplexityFields;
}
export interface DeleteUsersFromWorkspaceResponseOK<S extends DeleteUsersFromWorkspaceRequest = DeleteUsersFromWorkspaceRequest> {
    data: {
        delete_users_from_workspace: Array<SelectUserReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteUsersFromWorkspaceFullResponseOK {
    data: {
        delete_users_from_workspace: UserReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=user.d.ts.map